package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Id;

/**
 * File: AlumnoActividad.java
 * Created: 2012-06-07
 * 
 * Contiene una actividad a la que est inscrita un alumnno.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "AlumnoActividad")
public class AlumnoActividad implements Serializable{
	private static final long serialVersionUID = 1L;
	private Integer idAlumno;
	private Integer idActividad;
	private String confirmado;
	private Alumno alumno;
	private Actividad actividad;

	/**
	 * Constructor vaco para Hibernate.
	 */
	public AlumnoActividad() {
	}

	/**
	 * Crea una nueva actividad inscrita por un alumno.
	 * 
	 * @param idAlumno    Identificador del alumno.
	 * @param idActividad Identificador de la actividad.
	 * @param confirmado  Indica si la inscripcin est confirmada o no.
	 */
	public AlumnoActividad(Integer idAlumno, Integer idActividad,
			String confirmado) {
		super();
		this.idAlumno = idAlumno;
		this.idActividad = idActividad;
		this.confirmado = confirmado;
	}

	// getters & setters
	@Id
	public Integer getIdAlumno() {
		return idAlumno;
	}

	public void setIdAlumno(Integer idAlumno) {
		this.idAlumno = idAlumno;
	}

	@Id
	public Integer getIdActividad() {
		return idActividad;
	}

	public void setIdActividad(Integer idActividad) {
		this.idActividad = idActividad;
	}

	public String getConfirmado() {
		return confirmado;
	}

	public void setConfirmado(String confirmado) {
		this.confirmado = confirmado;
	}

	@ManyToOne()
	@JoinColumn(name="idAlumno", insertable=false, updatable=false)
	public Alumno getAlumno() {
		return alumno;
	}

	public void setAlumno(Alumno alumno) {
		this.alumno = alumno;
	}

	@ManyToOne()
	@JoinColumn(name="idActividad", insertable=false, updatable=false)
	public Actividad getActividad() {
		return actividad;
	}

	public void setActividad(Actividad actividad) {
		this.actividad = actividad;
	}
}
