package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import java.io.Serializable;

import javax.persistence.Entity;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;
import javax.persistence.Id;

/**
 * File: PadreActividad.java
 * Created: 2012-06-07
 * 
 * Contiene una actividad a la que est inscrita un alumnno.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "PadreActividad")
public class PadreActividad implements Serializable{
	private static final long serialVersionUID = 1L;
	private Integer idPadre;
	private Integer idActividad;
	private String confirmado;
	private Padre padre;
	private Actividad actividad;
	
	/**
	 * Constructor vaco para Hibernate.
	 */
	public PadreActividad() {
	}

	/**
	 * Crea una nueva actividad inscrita por un padre/madre/tutor.
	 * 
	 * @param idPadre     Identificador del padre/madre/tutor.
	 * @param idActividad Identificador de la actividad.
	 * @param confirmado  Indica si la inscripcin est confirmada o no.
	 */
	public PadreActividad(Integer idPadre, Integer idActividad,
			String confirmado) {
		super();
		this.idPadre = idPadre;
		this.idActividad = idActividad;
		this.confirmado = confirmado;
	}

	// getters & setters
	@Id
	public Integer getIdPadre() {
		return idPadre;
	}

	public void setIdPadre(Integer idPadre) {
		this.idPadre = idPadre;
	}

	@Id
	public Integer getIdActividad() {
		return idActividad;
	}

	public void setIdActividad(Integer idActividad) {
		this.idActividad = idActividad;
	}

	public String getConfirmado() {
		return confirmado;
	}

	public void setConfirmado(String confirmado) {
		this.confirmado = confirmado;
	}

	@ManyToOne()
	@JoinColumn(name="idPadre", insertable=false, updatable=false)
	public Padre getPadre() {
		return padre;
	}

	public void setPadre(Padre padre) {
		this.padre = padre;
	}

	@ManyToOne()
	@JoinColumn(name="idActividad", insertable=false, updatable=false)
	public Actividad getActividad() {
		return actividad;
	}

	public void setActividad(Actividad actividad) {
		this.actividad = actividad;
	}
}
