package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.OneToMany;

import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;

/**
 * File: Socio.java
 * Created: 2012-06-01
 * 
 * Contiene los datos de un socio.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "Socio")
public class Socio extends Usuario{
	private String direccion;
	private Date fechaSolicitud;
	private String valido;
	private List<Padre> padres;
	private List<Alumno> alumnos;
	
	/**
	 * Constructor vaco para Hibernate.
	 */
	public Socio() {
		super(ConstantesNegocio.USUARIO_SOCIO);
	}

	/**
	 * Crea un nuevo socio.
	 * 
	 * @param usuario        Identificador nico de usuario para el acceso al sistema.
	 * @param password       Password del usuario.
	 * @param direccion      Direccin del socio.
	 * @param fechaSolicitud Fecha de solicitud de incorporacin como socio.
	 * @param valido         Indica si el socio es vlido o no. Los socios se invalidan al finalizar
	 *                       un curso.
	 * @param padres         Lista de padres de la ficha de socio.
	 * @param alumnos        Lista de alumnos de la ficha de socio.
	 */
	public Socio(String usuario, String password,
			String direccion, Date fechaSolicitud, String valido,
			List<Padre> padres, List<Alumno> alumnos) {
		super(usuario, password, ConstantesNegocio.USUARIO_SOCIO);
		this.direccion = direccion;
		this.fechaSolicitud = fechaSolicitud;
		this.valido = valido;
		this.padres = padres;
		this.alumnos = alumnos;
	}

	// getters & setters
	public String getDireccion() {
		return direccion;
	}

	public void setDireccion(String direccion) {
		this.direccion = direccion;
	}

	public Date getFechaSolicitud() {
		return fechaSolicitud;
	}

	public void setFechaSolicitud(Date fechaSolicitud) {
		this.fechaSolicitud = fechaSolicitud;
	}

	public String getValido() {
		return valido;
	}

	public void setValido(String valido) {
		this.valido = valido;
	}

	@OneToMany(mappedBy="usuario", cascade={CascadeType.ALL})
	public List<Padre> getPadres() {
		return padres;
	}

	public void setPadres(List<Padre> padres) {
		this.padres = padres;
	}

	@OneToMany(mappedBy="usuario", cascade={CascadeType.ALL})
	public List<Alumno> getAlumnos() {
		return alumnos;
	}

	public void setAlumnos(List<Alumno> alumnos) {
		this.alumnos = alumnos;
	}

	@Override
	public String toString() {
		return "Socio [direccion=" + direccion + ", fechaSolicitud="
				+ fechaSolicitud + ", valido=" + valido + ", padres=" + padres
				+ ", alumnos=" + alumnos + "]";
	}
}
