package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Inheritance;
import javax.persistence.InheritanceType;
import javax.persistence.Table;

/**
 * File: Usuario.java
 * Created: 2012-06-01
 * 
 * Contiene los datos de acceso de un usuario de la aplicacin.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "Usuario")
@Inheritance(strategy=InheritanceType.JOINED)
public class Usuario {
	protected String usuario;
	protected String password;
	protected String tipo;

	/**
	 * Constructor vaco para Hibernate.
	 */
	public Usuario() {
	}
	
	/**
	 * Crea un nuevo usuario.
	 * 
	 * @param usuario  Identificador nico de usuario para el acceso al sistema.
	 * @param password Password del usuario.
	 * @param tipo     Tipo de usuario (administrador o socio).
	 *                 Ver ConstantesNegocio.USUARIO_*
	 */
	public Usuario(String usuario, String password, String tipo) {
		this.usuario = usuario;
		this.password = password;
		this.tipo = tipo;
	}

	public Usuario(String tipo) {
		super();
		this.tipo = tipo;
	}

	// getters & setters
	@Id
	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getTipo() {
		return tipo;
	}

	public void setTipo(String tipo) {
		this.tipo = tipo;
	}

	@Override
	public String toString() {
		return "Usuario [usuario=" + usuario
				+ ", password=" + password
				+ ", tipo=" + tipo + "]";
	}
}
