package edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS;

import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Usuario;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.BusinessObject;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.UsuarioBO;
import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPUtils;

/**
 * File: SeguridadAS.java
 * Created: 2012-06-01
 * 
 * Fachada de la capa de negocio para funciones relacionadas con la seguridad.
 * 
 * @author Jos Alonso de Motta
 */
public class SeguridadAS extends BusinessObject {
	private final static Logger logger = Logger.getLogger(MTPUtils.getPackageName());

	/**
	 * Obtiene un usuario en base a su identificador.
	 * 
	 * @param usuario Identificador del usuario a obtener.
	 * @return        Usuario encontrado o null si no se encuentra o hay algn error.
	 */
	public Usuario getUsuario(String usuario){
		Usuario result = null;
		try {
			UsuarioBO usuarioBO = new UsuarioBO();
			session.getTransaction().begin();
			result = usuarioBO.getUsuario(usuario);
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error obteniendo usuario. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return result;
	}

	/**
	 * En base a un Usuario dado (identificador y contrasea), verifica si es un usuario vlido del
	 * sistema y qu tipo de usuario es (administrador o socio).
	 * 
	 * @param usuarioCheck Usuario a comprobar su existencia (se comprueba en base al identificador
	 *                     y la contrasea).
	 * @return             Uno de los valores ConstantesNegocio.LOGIN_* indicando el tipo de usuario
	 *                     en caso de que sea vlido o si no lo es el tipo de error obtenido.
	 */
	public int login(Usuario usuarioCheck){
		int result = ConstantesNegocio.LOGIN_ERROR;
		try {
			UsuarioBO usuarioBO = new UsuarioBO();
			session.getTransaction().begin();
			result = usuarioBO.comprobarUsuario(usuarioCheck);
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error comprobando login. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			result = ConstantesNegocio.LOGIN_ERROR;
		}
		return result;
	}
}
