package edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS;

import java.util.Iterator;
import java.util.List;
import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Actividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Alumno;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.AlumnoActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.AlumnoActividadPeriodo;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Padre;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PadreActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PadreActividadPeriodo;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PeriodoActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.ActividadBO;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.BusinessObject;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.SocioBO;
import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPUtils;

/**
 * File: SociosAS.java
 * Created: 2012-06-06
 * 
 * Fachada de la capa de negocio para funciones relacionadas con los socios.
 * 
 * @author Jos Alonso de Motta
 */
public class SociosAS extends BusinessObject {
	private final static Logger logger = Logger.getLogger(MTPUtils.getPackageName());

	/**
	 * Modifica los datos de un socio.
	 * 
	 * @param socio Socio con los valores actuales a guardar.
	 * @return      true si la operacin tiene xito, false en caso contrario.
	 */
	public boolean actualizarSocio(Socio socio){
		try {
			session.getTransaction().begin();
			(new SocioBO()).actualizarSocio(socio);
			session.getTransaction().commit();
			return true;
		} catch (Exception e) {
			logger.warning("Error actualizando socio. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return false;
		}
	}

	/**
	 * Inscribe a una relacin de padres y/o alumnos a una actividad, seleccionando todos los periodos
	 * activos (no pasados) para dicha actividad.
	 *  
	 * @param idActividad Identificador de actividad.
	 * @param idPadres    Lista de identificadores de los padres a inscribir.
	 * @param idAlumnos   Lista de identificadores de los alumnos a inscribir.
	 * @return            true si la operacin tiene xito, false en caso contrario.
	 */
	public boolean crearInscripciones(Integer idActividad, List<Integer> idPadres, List<Integer> idAlumnos) {
		try {
			session.getTransaction().begin();
			SocioBO socioBO = new SocioBO();
			ActividadBO actividadBO = new ActividadBO();
			Actividad actividad = (new ActividadBO()).getActividad(idActividad);
			String confirmado = null;
			if(actividad.getRequiereValidar()==ConstantesNegocio.ACTIVIDAD_SI_REQUIERE_VALIDAR){
				confirmado = ConstantesNegocio.INSCRIPCION_NO_CONFIRMADA;
			}else{
				confirmado = ConstantesNegocio.INSCRICPION_CONFIRMADA;
			}
			Iterator<Integer> itPadres = idPadres.iterator();
			List<PeriodoActividad> periodos = actividadBO.getPeriodosActivos(idActividad);
			while(itPadres.hasNext()){
				Integer idPadre = itPadres.next();
				PadreActividad padreActividad = new PadreActividad(idPadre, idActividad, confirmado);
				socioBO.crearPadreActividad(padreActividad);
				Iterator<PeriodoActividad> itPeriodos = periodos.iterator();
				while(itPeriodos.hasNext()){
					PeriodoActividad periodo = itPeriodos.next();
					socioBO.crearPadreActividadPeriodo(new PadreActividadPeriodo(idPadre, idActividad, periodo.getIdPeriodo()));
				}
			}
			Iterator<Integer> itAlumnos = idAlumnos.iterator();
			while(itAlumnos.hasNext()){
				Integer idAlumno = itAlumnos.next();
				AlumnoActividad alumnoActividad = new AlumnoActividad(idAlumno, idActividad, confirmado);
				socioBO.crearAlumnoActividad(alumnoActividad);
				Iterator<PeriodoActividad> itPeriodos = periodos.iterator();
				while(itPeriodos.hasNext()){
					PeriodoActividad periodo = itPeriodos.next();
					socioBO.crearAlumnoActividadPeriodo(new AlumnoActividadPeriodo(idAlumno, idActividad, periodo.getIdPeriodo()));
				}
			}
			session.getTransaction().commit();
			return true;
		} catch (Exception e) {
			logger.warning("Error creando PadreActividad. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return false;
		}
	}

	/**
	 * Da de baja a un alumno en una actividad (incluidos todos los periodos). El alumno debe
	 * pertenecer al identificador de socio indicado.
	 * 
	 * @param usuario     Identificador del socio al que pertenece el alumno.
	 * @param idAlumno    Identificador del alumnos a dar de baja en la actividad.
	 * @param idActividad Identificador de la actividad en que se da de baja.
	 * @return            true si la operacin tiene xito, false en caso contrario.
	 */
	public boolean eliminarAlumnoActividad(String usuario, Integer idAlumno, Integer idActividad){
		SocioBO socioBO = new SocioBO();
		AlumnoActividad alumnoActividad = null;
		boolean result = false;
		try {
			session.getTransaction().begin();
			Alumno alumno = socioBO.getAlumno(usuario, idAlumno);
			if(alumno!=null){
				alumnoActividad = socioBO.getAlumnoActividad(idAlumno, idActividad);
				if(alumnoActividad!=null){
					(new SocioBO()).eliminarAlumnoActividad(alumnoActividad);
					result = true;
				}
			}
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error eliminando alumnoActividad por usuario, alumno, actividad. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return result;
	}

	/**
	 * Da de baja a un padre en una actividad (incluidos todos los periodos). El padre debe
	 * pertenecer al identificador de socio indicado.
	 * 
	 * @param usuario     Identificador del socio al que pertenece el alumno.
	 * @param idPadre     Identificador del padres a dar de baja en la actividad.
	 * @param idActividad Identificador de la actividad en que se da de baja.
	 * @return            true si la operacin tiene xito, false en caso contrario.
	 */
	public boolean eliminarPadreActividad(String usuario, Integer idPadre, Integer idActividad){
		SocioBO socioBO = new SocioBO();
		PadreActividad padreActividad = null;
		boolean result = false;
		try {
			session.getTransaction().begin();
			Padre padre = socioBO.getPadre(usuario, idPadre);
			if(padre!=null){
				padreActividad = socioBO.getPadreActividad(idPadre, idActividad);
				if(padreActividad!=null){
					(new SocioBO()).eliminarPadreActividad(padreActividad);
					result = true;
				}
			}
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error eliminando padreActividad por usuario, padre, actividad. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return result;
	}

	/**
	 * Da de baja a un socio.
	 * 
	 * @param usuario Identificador de socio a dar de baja.
	 * @return        true si la operacin tiene xito, false en caso contrario.
	 */
	public boolean eliminarSocio(String usuario){
		try {
			session.getTransaction().begin();
			SocioBO socioBO = new SocioBO();
			Socio socio = socioBO.getSocio(usuario);
			if(socio!=null){
				socioBO.eliminarSocio(socio);
			}else{
				throw new Exception("Socio no encontrado");
			}
			session.getTransaction().commit();
			return true;
		} catch (Exception e) {
			logger.warning("Error eliminando socio. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return false;
		}
	}

	/**
	 * Obtiene la relacin de alumnos de un socio.
	 * 
	 * @param socio Socio del que se quieren obtener los alumnos.
	 * @return      Lista de alumnos del socio, null en caso de error.
	 */
	public List<Alumno> getAlumnos(Socio socio){
		try {
			session.getTransaction().begin();
			List<Alumno> alumnos = (new SocioBO()).getAlumnos(socio);
			session.getTransaction().commit();
			return alumnos;
		} catch (Exception e) {
			logger.warning("Error obteniendo lista de alumnos de un socio. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return null;
		}
	}

	/**
	 * Obtiene la relacin de inscripciones a actividades de todos los alumnos de un socio.
	 *  
	 * @param socio Socio del que se quieren obtener las inscripciones a actividades.
	 * @return      Lista de inscripciones de alumnos a actividades.
	 */
	public List<AlumnoActividad> getInscripcionesAlumnos(Socio socio){
		List<AlumnoActividad> actividadesAlumnos = null;
		try {
			session.getTransaction().begin();
			actividadesAlumnos = (new SocioBO()).getActividadesAlumnoPorSocio(socio);
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error obteniendo inscripciones de los alumnos. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return actividadesAlumnos;
	}

	/**
	 * Obtiene la relacin de inscripciones a actividades de todos los padres de un socio.
	 *  
	 * @param socio Socio del que se quieren obtener las inscripciones a actividades.
	 * @return      Lista de inscripciones de padres a actividades.
	 */
	public List<PadreActividad> getInscripcionesPadres(Socio socio){
		List<PadreActividad> actividadesPadres = null;
		try {
			session.getTransaction().begin();
			actividadesPadres = ((new SocioBO()).getActividadesPadrePorSocio(socio));
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error obteniendo inscripciones de los padres. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return actividadesPadres;
	}

	/**
	 * Obtiene la relacin de padres de un socio.
	 * 
	 * @param socio Socio del que se quieren obtener los padres.
	 * @return      Lista de padres del socio, null en caso de error.
	 */
	public List<Padre> getPadres(Socio socio){
		try {
			session.getTransaction().begin();
			List<Padre> padres = (new SocioBO()).getPadres(socio);
			session.getTransaction().commit();
			return padres;
		} catch (Exception e) {
			logger.warning("Error obteniendo lista de padres de un socio. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return null;
		}
	}

	/**
	 * Obtiene un socio en base al identificador. Se fuerza al motor de persistencia a obtener
	 * los datos de padres y alumnos para su lectura posterior sin conexin a la base de datos.
	 * 
	 * @param usuario Identificador de socio.
	 * @return        Socio ledo o null en caso de error.
	 */
	public Socio getSocio(String usuario){
		Socio result = null;
		try {
			SocioBO socioBO = new SocioBO();
			session.getTransaction().begin();
			result = socioBO.getSocio(usuario);
			// Forzar a leer los datos de padres y alumnos
			result.getPadres().size();
			result.getAlumnos().size();
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error obteniendo socio por usuario. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return result;
	}

	/**
	 * Obtiene todos los socios. Se fuerza al motor de persistencia a obtener
	 * los datos de padres y alumnos para su lectura posterior sin conexin a la base de datos. 
	 * 
	 * @return Lista de socios o null en caso de error.
	 */
	public List<Socio> getSocios(){
		try {
			session.getTransaction().begin();
			List<Socio> socios = (new SocioBO()).getSocios();
			Iterator<Socio> itSocio = socios.iterator();
			while(itSocio.hasNext()){
				Socio s = itSocio.next();
				// Forzar a leer los datos de padres y alumnos
				s.getPadres().size();
				s.getAlumnos().size();
			}
			session.getTransaction().commit();
			return socios;
		} catch (Exception e) {
			logger.warning("Error obteniendo lista de socios. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return null;
		}
	}
	
	/**
	 * Marca como invlidos a todos los socios.
	 * 
	 * @return El nmero de socios invalidados o -1 si hubo algn error.
	 */
	public int invalidarSocios(){
		try {
			session.getTransaction().begin();
			int filasAfectadas = (new SocioBO()).invalidarSocios();
			session.getTransaction().commit();
			return filasAfectadas;
		} catch (Exception e) {
			logger.warning("Error invalidando fichas de socios. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return -1;
		}
	}
}
