package edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO;

import java.util.List;

import org.hibernate.Query;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Actividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PeriodoActividad;

/**
 * File: ActividadBO.java
 * Created: 2012-06-08
 * 
 * Objeto de negocio para las operaciones relacionadas con actividades.  
 * 
 * @author Jos Alonso de Motta
 */
public class ActividadBO extends BusinessObject {

	/**
	 * Recupera de la base de datos una actividad.
	 * 
	 * @param idActividad Identificador de la actividad a recuperar.
	 * @return            Actividad encontrada.
	 */
	public Actividad getActividad(int idActividad){
		return (Actividad)session.get(Actividad.class, idActividad);
	}
	
	/**
	 * Recupera de la base de datos las actividades con periodos activos (no pasados).
	 * 
	 * @return Lista de actividades con periodos activos (no pasados).
	 */
	public List<Actividad> getActividadesActivas(){
		Query query = session.createQuery("from Actividad a where idActividad in (select periodoactividad.idActividad from PeriodoActividad as periodoactividad where inicio > current_date or fin > current_date)");
		@SuppressWarnings("unchecked")
		List<Actividad> actividades = query.list();
		return actividades;
	}

	/**
	 * Recupera de la base de datos los periodos activos (no pasados) de una actividad.
	 * @param idActividad
	 * @return
	 */
	public List<PeriodoActividad> getPeriodosActivos(int idActividad){
		Query query = session.createQuery("from PeriodoActividad a where idActividad = :idActividad and (inicio > current_date or fin > current_date)")
				.setParameter("idActividad", idActividad);
		@SuppressWarnings("unchecked")
		List<PeriodoActividad> periodos = query.list();
		return periodos;
	}
}
