package edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO;

import java.util.List;

import org.hibernate.Criteria;
import org.hibernate.criterion.Projections;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.SolicitudSocio;

/**
 * File: SolicitudSocioBO.java
 * Created: 2012-05-25
 * 
 * Objeto de negocio para gestionar las solicitudes de socios.
 * 
 * @author Jos Alonso de Motta
 */
public class SolicitudSocioBO extends BusinessObject {

	/**
	 * Registra en la base de datos una nueva solicitud de socio.
	 * 
	 * @param solicitudSocio Solicitud de socio a registrar.
	 */
	public void crearSolicitudSocio(SolicitudSocio solicitudSocio) {
		session.persist(solicitudSocio);
	}

	/**
	 * Elimina de la base de datos una solicitud para hacerse socio.
	 * 
	 * @param usuario
	 */
	public void eliminarSolicitudSocio(SolicitudSocio solicitudSocio){
		session.delete(solicitudSocio);
	}

	/**
	 * Obtiene de la base de datos el nmero de solicitudes de hacerse socio pendientes. 
	 * 
	 * @return Nmero de solicitudes de hacerse socio pendientes.
	 */
	public int getNumSolicitudesPendientes(){
		Criteria criteria = session.createCriteria(SolicitudSocio.class);
		criteria.setProjection(Projections.rowCount());
		@SuppressWarnings("unchecked")
		List<Long> registros = criteria.list();
		return registros.get(0).intValue();
	}

	/**
	 * Carga de la base de datos todas las solicitudes para hacerse socio.
	 * 
	 * @return Lista de solicitudes para hacerse socio.
	 */
	public List<SolicitudSocio> getSolicitudesSocio() {
		@SuppressWarnings("unchecked")
		List<SolicitudSocio> solicitudesSocios = session.createQuery("from SolicitudSocio").list();
		return solicitudesSocios;
	}
	
	/**
	 * Carga de la base de datos la solicitud para hacerse socio en base al identificador.
	 * 
	 * @param usuario Identificador de socio de la solicitud.
	 * @return        Solicitud para hacerse socio o null si no existe.
	 */
	public SolicitudSocio getSolicitudSocioPorUsuario(String usuario){
		return (SolicitudSocio)session.get(SolicitudSocio.class, usuario);
	}
}
