package edu.uoc.pfc.j2ee.jalonsod.ampa.integration;

import java.util.logging.Logger;

import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;

import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: HibernatePersistenceHelper.java
 * Created: 2012-05-22
 * 
 * Objeto de integracin con Hibernate.
 * Funciona como singleton para configurar y obtener sesiones de Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
public class HibernatePersistenceHelper {
	private final static Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);

	private static final SessionFactory sessionFactory = buildSessionFactory();
	
	/**
	 * Carga la configuracin de Hibernate y devuelve el objeto para crear sesiones.
	 * 
	 * @return Fbrica de sesiones para interactuar con la base de datos.
	 */
	@SuppressWarnings("deprecation")
	private static SessionFactory buildSessionFactory() {
		SessionFactory sessionFactory;
		try {
			sessionFactory = new Configuration().configure().buildSessionFactory();
			logger.config("Hibernate session factory built.");
			return sessionFactory;
		} catch (Exception e) {
			logger.severe("Exception while building Hibernate session factory.");
			e.printStackTrace();
		}
		return null;
	}

	/**
	 * Obtiene la sesin actual para interactuar con la base de datos.
	 * 
	 * @return Sesin actual.
	 */
	public static Session getCurrentSession() {
		return sessionFactory.getCurrentSession();
	}
	
	/**
	 * Devuelve una nueva sesin para interactuar con la base de datos.
	 * @return
	 */
	public static Session openSession() {
		return sessionFactory.openSession();
	}
}
