package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Administrador;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Usuario;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SociosAS;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SolicitudAltaAS;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;


/**
 * File: HomeModel.java
 * Created: 2012-05-22
 * 
 * Modelo de presentacin para pgina de inicio.
 * 
 * @author Jos Alonso de Motta
 */
public class HomeModel {
	// Parmetros de salida
	private int numeroSolicitudesPendientes;
	private int respuesta;
	private Socio socio;

	/**
	 * Accin para cargar las distintas pginas iniciales (usuario sin identificar, socio o
	 * administrador).
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return IS_ADMINISTRADOR si el usuario de la sesin es un administrador, IS_SOCIO si el usuario
	 * de la sesin es un socio, IS_NOUSER si no hay usuario en la sesin.
	 */
	public String run(RequestData requestData){
		Usuario usuario = UtilesModelos.getUsuario(requestData);
		if(usuario instanceof Administrador){
			respuesta = ConstantesNegocio.LOGIN_ADMIN;
			loadNumeroSolicitudesPendientes();
			return UtilesModelos.RESULT_IS_ADMINISTRADOR;
		}else if (usuario instanceof Socio){
			socio = (new SociosAS()).getSocio(usuario.getUsuario());
			respuesta = ConstantesNegocio.LOGIN_SOCIO;
			return UtilesModelos.RESULT_IS_SOCIO;
		}else{
			respuesta = ConstantesNegocio.LOGIN_LOGOUT;
			return UtilesModelos.RESULT_IS_NOUSER;
		}
	}

	/**
	 * Carga para la vista el nmero de solicitudes de alta de socios pendientes.
	 */
	public void loadNumeroSolicitudesPendientes() {
		setNumeroSolicitudesPendientes((new SolicitudAltaAS()).getNumSolicitudesPendientes());
	}

	// getters & setters
	public int getNumeroSolicitudesPendientes() {
		return numeroSolicitudesPendientes;
	}

	public void setNumeroSolicitudesPendientes(int numeroSolicitudesPendientes) {
		this.numeroSolicitudesPendientes = numeroSolicitudesPendientes;
	}

	public int getRespuesta() {
		return respuesta;
	}

	public void setRespuesta(int respuesta) {
		this.respuesta = respuesta;
	}

	public Socio getSocio() {
		return socio;
	}

	public void setSocio(Socio socio) {
		this.socio = socio;
	}
}
