package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import java.util.List;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SociosAS;

/**
 * File: SociosAdminModel.java
 * Created: 2012-06-09
 * 
 * Modelo de presentacin para gestin de socios por parte del administrador.  
 * 
 * @author Jos Alonso de Motta
 */
public class SociosAdminModel {
	// Parmetros de entrada
	private String usuario;
	
	// Parmetros de salida
	private List<Socio> socios;
	private boolean resultado = false;
	private String operacion = null;
	private Socio socio;
	private int numSociosInvalidados;

	/**
	 * Accin para dar de baja un socio (por parte del administrador).
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @return OK si los datos de socios se cargan correctamente, false en caso contrario.
	 */
	public String runBaja() {
		operacion = UtilesModelos.OPERACION_DELETE;
		resultado = ((new SociosAS()).eliminarSocio(usuario));
		if(loadSocios()){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}

	/**
	 * Accin para cargar la ficha de socios.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @return OK si carga correctamente la ficha, ERROR en caso contrario.
	 */
	public String runFicha() {
		operacion = UtilesModelos.OPERACION_SELECT;
		socio = (new SociosAS()).getSocio(usuario);
		resultado = (socio!=null);
		if(socio!=null){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}
	/**
	 * Accin para invalidar todas las fichas de socios.
	 * 
	 * @return OK si se invalida correctamente, ERROR en caso contrario.
	 */
	public String runFinCurso(){
		operacion = UtilesModelos.OPERACION_UPDATE;
		int filasAfectadas = (new SociosAS()).invalidarSocios();
		if(filasAfectadas>=0){
			numSociosInvalidados = filasAfectadas;
			resultado = true;
			return UtilesModelos.RESULT_OK;
		}else{
			numSociosInvalidados = 0;
			resultado = false;
			return UtilesModelos.RESULT_OK;
		}
	}

	/**
	 * Accin para obtener la lista de socios.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @return OK si los datos de socios se cargan correctamente, false en caso contrario.
	 */
	public String runList() {
		if(loadSocios()){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}
	
	/**
	 * Carga la lista de socios en la propiedad correspondiente.
	 * 
	 * @return true si se carga correctamente, false en caso contrario.
	 */
	public boolean loadSocios(){
		socios = (new SociosAS()).getSocios();
		if(socios!=null){
			return true;
		}else{
			return false;
		}
	}

	// getters & setters
	public List<Socio> getSocios() {
		return socios;
	}

	public void setSocios(List<Socio> socios) {
		this.socios = socios;
	}

	public boolean isResultado() {
		return resultado;
	}

	public void setResultado(boolean resultado) {
		this.resultado = resultado;
	}

	public String getOperacion() {
		return operacion;
	}

	public void setOperacion(String operacion) {
		this.operacion = operacion;
	}

	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public Socio getSocio() {
		return socio;
	}

	public void setSocio(Socio socio) {
		this.socio = socio;
	}

	public int getNumSociosInvalidados() {
		return numSociosInvalidados;
	}

	public void setNumSociosInvalidados(int numSociosInvalidados) {
		this.numSociosInvalidados = numSociosInvalidados;
	}
}
