package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import java.util.List;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.SolicitudSocio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SolicitudAltaAS;

/**
 * File: SolicitudAltaPendienteModel.java
 * Created: 2012-06-08
 * 
 * Modelo de presentacin para gestin de solicitudes de alta pendientes.  
 * 
 * @author Jos Alonso de Motta
 */
public class SolicitudAltaPendienteModel {
	// Parmetros de entrada
	private String usuario;
	
	// Parmetros de salida
	private List<SolicitudSocio> solicitudesSocio;
	private String operacion = null;
	private boolean resultado = false;

	/**
	 * Accin para obtener la lista de solicitudes de alta pendientes.
	 * 
	 * @return OK si se cargan bien las solicitudes de alta pendientes, ERROR en caso contrario.
	 */
	public String runList() {
		operacion = UtilesModelos.OPERACION_LIST;
		if(loadSolicitudesSocio()){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}
	
	/**
	 * Accin para registrar como socio una solicitud de alta pendiente.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @return OK si se cargan bien las solicitudes de alta pendientes, ERROR en caso contrario.
	 */
	public String runValidar() {
		operacion = UtilesModelos.OPERACION_INSERT;
		if((new SolicitudAltaAS()).validarSolicitud(usuario)){
			if(loadSolicitudesSocio()){
				resultado = true;
				return UtilesModelos.RESULT_OK;
			}else{
				return UtilesModelos.RESULT_ERROR;
			}
		}else{
			resultado = false;
			return UtilesModelos.RESULT_OK;
		}
	}

	/**
	 * Accin para anular/cancelar una solicitud de alta pendiente.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @return OK si se cargan bien las solicitudes de alta pendientes, ERROR en caso contrario.
	 */
	public String runAnular() {
		operacion = UtilesModelos.OPERACION_DELETE;
		if((new SolicitudAltaAS()).anularSolicitud(usuario)){
			if(loadSolicitudesSocio()){
				resultado = true;
				return UtilesModelos.RESULT_OK;
			}else{
				return UtilesModelos.RESULT_ERROR;
			}
		}else{
			resultado = false;
			return UtilesModelos.RESULT_OK;
		}
	}

	/**
	 * Carga en la propiedad solicitudesSocio las solicitudes de alta pendientes.
	 * 
	 * @return true si carga correctamente las solicitudes, false en caso contrario.
	 */
	public boolean loadSolicitudesSocio(){
		solicitudesSocio = (new SolicitudAltaAS()).getSolicitudesSocio();
		return (solicitudesSocio!=null);
	}

	// getters & setters
	public List<SolicitudSocio> getSolicitudesSocio() {
		return solicitudesSocio;
	}

	public void setSolicitudesSocio(List<SolicitudSocio> solicitudesSocio) {
		this.solicitudesSocio = solicitudesSocio;
	}

	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public String getOperacion() {
		return operacion;
	}

	public void setOperacion(String operacion) {
		this.operacion = operacion;
	}

	public boolean isResultado() {
		return resultado;
	}

	public void setResultado(boolean resultado) {
		this.resultado = resultado;
	}
}
