package edu.uoc.pfc.j2ee.jalonsod.mtp;

import java.lang.reflect.Method;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.logging.ConsoleHandler;
import java.util.logging.Handler;
import java.util.logging.Level;
import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: MTPUtils.java
 * Created: 2012-04-28
 * 
 * Auxiliary methods not attached to specific functionality for use INSIDE the framework.
 * 
 * @author Jos Alonso de Motta
 */
public class MTPUtils {
	private final static Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);
	
	/**
	 * Returns the package name of the caller method.
	 * 
	 * @return the package name of the caller method.
	 */
	public static String getPackageName(){
		String className = Thread.currentThread().getStackTrace()[2].getClassName();
		String packageName = className.substring(0, className.lastIndexOf("."));
		return packageName;
	}

	/**
	 * Returns the class name of the caller method.
	 * 
	 * @return the class name of the caller method.
	 */
	public static String getClassName(){
		return Thread.currentThread().getStackTrace()[2].getClassName();
	}

	/**
	 * Returns the method name of the caller method.
	 * 
	 * @return the method name of the caller method.
	 */
	public static String getMethodName(){
		return Thread.currentThread().getStackTrace()[2].getMethodName();
	}
	
	public static void setLoggerToLevel(String l){
		Level level = Level.WARNING;
		if(l!=null){
			level = Level.parse(l);
		}
		Handler consoleHandler = new ConsoleHandler();
		consoleHandler.setLevel(level);
		Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);
		logger.setLevel(level);
		logger.addHandler(consoleHandler);
		System.out.println("Logger " + RequestData.MTP_LOGGER + " set to level " + level);
	}
	
	/**
	 * Gets the attribute of a Java Bean object with reflection mechanisms. The object must conform
	 * with the Sun Java Beans components model. Will invoke the getter method of the supplied attribute.
	 * @param object the Java Bean object.
	 * @param attributeName name of the attribute to extract from the Java Bean object.
	 * @return the attribute extracted from the Java Bean object.
	 */
	public static Object getBeanAttrib(Object object, String attributeName) {
		String methodName = "get"
				+ attributeName.substring(0, 1).toUpperCase()
				+ attributeName.substring(1);
		Object returnValue = null;
		try {
			Method method = object.getClass().getMethod(methodName);
			returnValue = method.invoke(object);
		} catch (Exception e) {
			logger.warning("Error while executing method " + object.getClass().getName() + methodName);
			e.printStackTrace();
		}
		return returnValue;
	}

	/**
	 * Parses a date stored in a string with a specific format mask.
	 * @param date string with the date value.
	 * @param format format mask of the string date.
	 * @return the date value.
	 */
	public static Date parseDate(String date, String format){
		SimpleDateFormat sdf = new SimpleDateFormat(format);
		Date result = null;
		try {
			result = new Date(sdf.parse(date).getTime());
		} catch (ParseException e) {
			result = null;
			e.printStackTrace();
			logger.info("ParseException while parsing date " + date + " with format " + format);
		}
		return result;
	}
}
