package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import java.util.Date;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPUtils;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.DateParameterInstance;

/**
 * File: DateParameter.java
 * Created: 2012-04-22
 * 
 * The Parameter configuration metadata for datatype <code>java.sql.Date</code>.
 * 
 * @author Jos Alonso de Motta
 * @see DateParameterInstance
 */
public class DateParameter extends Parameter {
	private Date defaultValue;
	private String dateFormat;
	
	/**
	 * Constructor of date parameter.
	 *  
	 * @throws ConfiguratorException throws when received parameters are invalid.
	 */
	protected DateParameter(String name, String datatype, boolean required,
			Validation validateMethod, boolean copyToModel,
			String modelAttribute, String dateFormat, String defaultValue) throws ConfiguratorException{
		super(name, datatype, required, validateMethod, copyToModel, modelAttribute);
		if(dateFormat==null){
			throw new ConfiguratorException("Date parameter must have format mask");
		}
		setDateFormat(dateFormat);
		if(!datatype.equalsIgnoreCase(Configurator.DATATYPE_DATE)){
			throw new ConfiguratorException("Cannot instantiate date parameter with datatype "+ datatype);
		}
		try{
			if(defaultValue!=null && !defaultValue.equals("") ){
				setDefaultValue(MTPUtils.parseDate(defaultValue, dateFormat));
			}else{
				setDefaultValue(null);
			}
			
		}catch (Exception e){
			throw new ConfiguratorException("Error setting default value for parameter " + name + " with datatype " + datatype);
		}
	}

	// getters & setters
	@Override
	public Date getDefaultValue() {
		return defaultValue;
	}
	@Override
	public void setDefaultValue(Object defaultValue) {
		setDefaultValue((Date)defaultValue);
	}
	public void setDefaultValue(Date defaultValue) {
		this.defaultValue = defaultValue;
	}
	public String getDateFormat() {
		return dateFormat;
	}
	public void setDateFormat(String dateFormat) throws ConfiguratorException {
		if(dateFormat==null||dateFormat.equals("")) throw new ConfiguratorException("Parameter element " + name + " has null or empty date format");
		this.dateFormat = dateFormat;
	}
	@Override
	public Class<?> getDatatypeReference(){
		return Date.class;
	}


	@Override
	public String toString() {
		return "DateParameter ["
				+ "name=" + name
				+ ", datatype=" + datatype
				+ ", required=" + required
				+ ", validateMethod=" + validateMethod
				+ ", copyToModel=" + copyToModel
				+ ", modelAttribute=" + modelAttribute
				+ ", defaultValue=" + defaultValue
				+ ", dateFormat=" + dateFormat
				+ "]";
	}
}
