package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import edu.uoc.pfc.j2ee.jalonsod.mtp.request.DoubleParameterInstance;

/**
 * File: DoubleParameter.java
 * Created: 2012-04-22
 * 
 * The Parameter configuration metadata for datatype <code>Double</code>.
 * 
 * @author Jos Alonso de Motta
 * @see DoubleParameterInstance
 */
public class DoubleParameter extends Parameter {
	private Double defaultValue;
	
	/**
	 * Constructor of date parameter.
	 *  
	 * @throws ConfiguratorException throws when received parameters are invalid.
	 */
	protected DoubleParameter(String name, String datatype, boolean required,
			Validation validateMethod, boolean copyToModel,
			String modelAttribute, String defaultValue) throws ConfiguratorException{
		super(name, datatype, required, validateMethod, copyToModel, modelAttribute);
		if(!datatype.equalsIgnoreCase(Configurator.DATATYPE_DOUBLE)){
			throw new ConfiguratorException("Cannot instantiate double parameter with datatype "+ datatype);
		}
		try{
			if(defaultValue!=null && !defaultValue.equals("") ){
				setDefaultValue(Double.parseDouble(defaultValue));
			}else{
				setDefaultValue(null);
			}
		}catch (Exception e){
			throw new ConfiguratorException("Error setting default value for parameter " + name + " with datatype " + datatype);
		}
	}

	// getters & setters
	@Override
	public Double getDefaultValue() {
		return defaultValue;
	}
	@Override
	public void setDefaultValue(Object defaultValue) {
		setDefaultValue((Double)defaultValue);
	}
	public void setDefaultValue(Double defaultValue) {
		this.defaultValue = defaultValue;
	}
	@Override
	public Class<?> getDatatypeReference(){
		return Double.class;
	}
}
