package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import java.util.Hashtable;

/**
 * File: Form.java
 * Created: 2012-04-22
 * 
 * Form configuration metadata.
 * A form is a group of parameters submitted by the user in a single request. Requests with the same
 * group of parameters can be of the same Form if they share the metadata information.
 * When a user submits a form, its parameters are loaded into a <code>FormInsance</code> and the
 * <code>Form</code> contains the metadata to manipulate those parameters.
 * 
 * @author Jos Alonso de Motta
 * @see Parameter
 * @see FormInstance
 */
public class Form {
	private String name;
	private Hashtable<String,Parameter> parameters;
	
	public Form(String name, Hashtable<String, Parameter> parameters) throws ConfiguratorException{
		setName(name);
		setParameters(parameters);
	}

	// getters & setters
	public String getName() {
		return name;
	}
	public void setName(String name) throws ConfiguratorException{
		if(name==null||name.equals("")) throw new ConfiguratorException("Form element has null or empty name");
		this.name = name;
	}
	public Hashtable<String, Parameter> getParameters() {
		return parameters;
	}
	public void setParameters(Hashtable<String, Parameter> parameters) throws ConfiguratorException{
		if(parameters==null) throw new ConfiguratorException("Form element " + name + " has null parameters");
		this.parameters = parameters;
	}

	@Override
	public String toString() {
		return "Form [name=" + name
				+ ", parameters=" + parameters + "]";
	}
}
