package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import edu.uoc.pfc.j2ee.jalonsod.mtp.request.IntegerParameterInstance;

/**
 * File: IntegerParameter.java
 * Created: 2012-04-22
 * 
 * The Parameter configuration metadata for datatype <code>Integer</code>.
 * 
 * @author Jos Alonso de Motta
 * @see IntegerParameterInstance
 */
public class IntegerParameter extends Parameter {
	public Integer defaultValue;
	
	/**
	 * Constructor of date parameter.
	 *  
	 * @throws ConfiguratorException trows when received parameters are invalid.
	 */
	protected IntegerParameter(String name, String datatype, boolean required,
			Validation validateMethod, boolean copyToModel,
			String modelAttribute, String defaultValue) throws ConfiguratorException{
		super(name, datatype, required, validateMethod, copyToModel, modelAttribute);
		if(!datatype.equalsIgnoreCase(Configurator.DATATYPE_INTEGER)){
			throw new ConfiguratorException("Cannot instantiate integer parameter with datatype "+ datatype);
		}
		try{
			if(defaultValue!=null && !defaultValue.equals("") ){
				setDefaultValue(Integer.parseInt(defaultValue));
			}else{
				setDefaultValue(null);
			}
		}catch (Exception e){
			throw new ConfiguratorException("Error setting default value for parameter " + name + " with datatype " + datatype);
		}
	}

	// getters & setters
	@Override
	public Integer getDefaultValue() {
		return defaultValue;
	}
	@Override
	public void setDefaultValue(Object defaultValue) {
		setDefaultValue((Integer)defaultValue);
	}
	public void setDefaultValue(Integer defaultValue) {
		this.defaultValue = defaultValue;
	}
	@Override
	public Class<?> getDatatypeReference(){
		return Integer.class;
	}
}
