package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import java.lang.reflect.Method;
import java.util.Date;

/**
 * File: Validation.java
 * Created: 2012-04-22
 * 
 * Contains validation metadata from configuration.
 * A validation is a method from an application class which validates the value of a parameter.
 * These methods must be static, receive a parameter of appropriate datatype and return a boolean
 * with true when validates the value and false when not validates.
 * 
 * @author Jos Alonso de Motta
 */
public class Validation {
	private String name;
	private String datatype;
	private String className;
	private Class<java.lang.Object> classReference;
	private String methodName;
	private Method methodReference;
	
	public Validation(String name, String className, String methodName, String datatype) throws ConfiguratorException{
		if(name==null||name.equals("")) throw new ConfiguratorException("Validation element has null or empty name");
		if(className==null||className.equals("")) throw new ConfiguratorException("Validation element " + name + " has null or empty class name");
		if(methodName==null||methodName.equals("")) throw new ConfiguratorException("Validation element " + name + " has null or empty method name");
		if(methodName==null||methodName.equals("")) throw new ConfiguratorException("Validation element " + name + " has null or empty datatype");
		this.setName(name);
		this.setDatatype(datatype);
		this.setClassName(className);
		this.setMethodName(methodName);
	}
	
	// getters & setters
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getDatatype() {
		return datatype;
	}
	public void setDatatype(String datatype) {
		this.datatype = datatype;
	}
	public String getClassName() {
		return className;
	}
	@SuppressWarnings("unchecked")
	public void setClassName(String className) throws ConfiguratorException {
		Class<java.lang.Object> c = null;
		try {
			c = (Class<java.lang.Object>)Class.forName(className);
		} catch (ClassNotFoundException e) {
			throw new ConfiguratorException("Model element " + name + " has nonexisting classname " + className, e);
		}
		this.className = className;
		setClassReference(c);
		setMethodReference(null);
	}
	public Class<java.lang.Object> getClassReference() {
		return classReference;
	}
	// Private because class reference is updated from setClassName
	private void setClassReference(Class<java.lang.Object> classReference) {
		this.classReference = classReference;
	}
	public String getMethodName() {
		return methodName;
	}
	@SuppressWarnings("rawtypes")
	public void setMethodName(String methodName) throws ConfiguratorException {
		Method r = null;
		Class c = null;
		if(getDatatype().equals(Configurator.DATATYPE_BOOLEAN)) {
			c = Boolean.class;
		}else if (getDatatype().equals(Configurator.DATATYPE_DATE)){
			c = Date.class;
		}else if (getDatatype().equals(Configurator.DATATYPE_DOUBLE)){
			c = Double.class;
		}else if (getDatatype().equals(Configurator.DATATYPE_INTEGER)){
			c = Integer.class;
		}else if (getDatatype().equals(Configurator.DATATYPE_STRING)){
			c = String.class;
		}
		try {
			r = getClassReference().getMethod(methodName, c);
			Class returnType = r.getReturnType(); 
			if(returnType!=boolean.class)
				throw new ConfiguratorException("Validation element " + getName() + " has validation method " + getClassName()+ "." + methodName + "." + methodName + "("+ getDatatype() + ") whit return type " + returnType + ", but it must return a boolean");
			setMethodReference(r);
		} catch (SecurityException e) {
			throw new ConfiguratorException("Validation element " + getName() + " has a SecurityException for method " + getClassName() + "." + methodName, e);
		} catch (NoSuchMethodException e) {
			throw new ConfiguratorException("Validation element " + getName() + " has a NoSuchMethodException for method " + getClassName() + "." + methodName, e);
		}
		this.methodName = methodName;
	}
	public Method getMethodReference() {
		return methodReference;
	}
	// Private because method reference is updated locally
	private void setMethodReference(Method methodReference) {
		this.methodReference = methodReference;
	}
	
	@Override
	public String toString() {
		return "Validation [name=" + name
				+ ", datatype=" + datatype
				+ ", className=" + className
				+ ", classReference=" + classReference
				+ ", methodName=" + methodName
				+ ", methodReference=" + methodReference + "]";
	}
}
