package edu.uoc.pfc.j2ee.jalonsod.mtp.helper;

import java.util.Enumeration;
import java.util.Hashtable;
import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Role;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestDataPrivate;

/**
 * File: AccessControl.java
 * Created: 2012-04-28
 * 
 * Implements the security check for session requests accessing models.
 * 
 * @author Jos Alonso de Motta
 */
public class AccessControl {
	private final static Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);

	/**
	 * Checks access from a session to a model.
	 * If model has no granted roles, access is granted.
	 * If model has granted roles, request session must have at least one of them.
	 * 
	 * @param requestData the MTP requestData of the current request.
	 */
	public void securityCheck(RequestDataPrivate requestData){
		Hashtable<String, Role> modelRoles = requestData.getModel().getGrantedRoles();
		Hashtable<String, Role> sessionRoles = requestData.getRoles();
		if(modelRoles.isEmpty()){
			requestData.authorize(true);
			logger.fine("Model has no granted roles. Access is granted.");
		}else{
			requestData.authorize(false);
			logger.fine("Model has granted roles. Check for model roles matching any session role");
		}
		if(sessionRoles!=null){
			Enumeration<String> modelRolesKeys = modelRoles.keys();
			while(modelRolesKeys.hasMoreElements()){
				String modelRoleKey = modelRolesKeys.nextElement();
				if(sessionRoles.containsKey(modelRoleKey)){
					logger.fine("Session has model role " + modelRoleKey + ". Access is granted.");
					requestData.authorize(true);
					break;
				}
			}
		}
	}
}
