package edu.uoc.pfc.j2ee.jalonsod.mtp.helper;

import java.lang.reflect.Method;
import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestDataPrivate;

/**
 * File: ModelRunner.java
 * Created: 2012-04-28
 * 
 * Executes the model supplied by application and records the result.
 * 
 * @author Jos Alonso de Motta
 */
public class ModelRunner {
	private final static Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);

	/**
	 * Runs the model instance stored in the requestData.
	 * The model instance run method can be of two forms:
	 * 1. With the requestData as a parameter
	 * 2. Without any parameters.
	 * 
	 * @param requestData the MTP requestData of the current request.
	 * @throws MTPException throws when there is any problem running the application model.
	 */
	public void run(RequestDataPrivate requestData) throws MTPException {
		try {
			Object modelInstance = requestData.getModelInstance();
			boolean sendRequestData = requestData.getModel().getSendRequestData();
			String methodName = requestData.getModel().getRunMethod();
			String modelResponse = null;
			Method m = null;
			if(sendRequestData){  // send request data as a parameter.
				m = modelInstance.getClass().getDeclaredMethod(methodName, RequestData.class);
				modelResponse = (String)m.invoke(modelInstance, (RequestData)requestData);
			}else{  // Don't send any parameters.
				m = modelInstance.getClass().getDeclaredMethod(methodName);
				modelResponse = (String)m.invoke(modelInstance);
			}
			requestData.setModelResponse(modelResponse);
		} catch (Exception e) {
			logger.warning("Exception " + e.getMessage() + " while running model "
					+ requestData.getModel().getClassName() + "." + requestData.getModel().getRunMethod());
			e.printStackTrace();
			throw new MTPException("Exception while calling "
					+ requestData.getModel().getClassName() + "." + requestData.getModel().getRunMethod(), e);
		}
	}
}
