package edu.uoc.pfc.j2ee.jalonsod.mtp.helper;

import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Model;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Result;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestDataPrivate;

/**
 * File: ViewMapperImpl.java
 * Created: 2012-04-28
 * 
 * ViewMapper implementation from the framework.
 * Map algorithm is based on the authorization, validation and response returned by the model.
 * 
 * @author Jos Alonso de Motta
 */
public class ViewMapperImpl implements ViewMapper {
	private final static Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);

	@Override
	public void setRequestView(RequestDataPrivate requestData) throws MTPException {
		Model model = requestData.getModel();
		String modelResponse = requestData.getModelResponse();
		boolean authorized = requestData.isAuthorized();
		boolean validated = requestData.isValidated();
		Result result = null;
		String view = null;
		// Check for authorization, validation and finally modelResponse=result.name
		if(authorized){
			if(validated){
				if(model!=null){
					if(modelResponse!=null){
						// Find for a result appropriate to modelResponse 
						result = model.getResults().get(modelResponse);
						if(result!=null){
							view = result.getNextView();
						}
					}
					if(result == null){
						// No result found using modelResponse
						result = model.getDefaultResult();
						view = result.getNextView();
					}
				}
			}else{
				result = model.getResultNoValidate();
				if(result!=null){
					view = result.getNextView();
				}else{
					view = requestData.getConfigurator().getDefaultValidationErrorView();
				}
			}
		}else{
			result = model.getResultSecurityError();
			if(result!=null){
				view = result.getNextView();
			}else{
				view = requestData.getConfigurator().getDefaultSecurityErrorView();
			}
		}
		if(view==null){
			// No view selected from model. Get default view of application
			view = requestData.getConfigurator().getDefaultView();
			logger.fine("Default view dispatched in model "
					+ ((model!=null)?model.getName():"null")
					+ " and response " + modelResponse );
		}
		logger.fine("View processing: authorized=" + authorized
				+ ", Validated=" + validated
				+ ", modelResponse=" + modelResponse
				+ ", view=" + view);
		requestData.setView(view);
		requestData.setResult(result);
	}
}
