package edu.uoc.pfc.j2ee.jalonsod.mtp.request;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.BooleanParameter;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Parameter;

/**
 * File: BooleanParameterInstance.java
 * Created: 2012-05-01
 * 
 * Holds a request parameter value of type <code>Boolean</code>.
 * 
 * @author Jos Alonso de Motta
 * @see BooleanParameter
*/
public class BooleanParameterInstance extends ParameterInstance {
	/**
	 * The value of the request parameter.
	 */
	Boolean value;

	public BooleanParameterInstance(Parameter parameter) {
		super(parameter);
		setValue(null);
	}

	@Override
	public Boolean getValue() {
		return value;
	}

	@Override
	public void setValue(Object value) {
		setValue((Boolean)value);
	}

	/**
	 * The setter of the value received as same datatype as the parameterInstance.
	 * 
	 * @param value the value to set.
	 */
	public void setValue(Boolean value) {
		this.value = value;
	}

	@Override
	public Boolean getDefaultValue() {
		return (Boolean)getParameter().getDefaultValue();
	}

	@Override
	public void setStringValue(String value) throws MTPException {
		try{
			if(value!=null && !value.equals("")){
				setValue(Boolean.parseBoolean(value));
			}else{
				setValueAsDefault();
			}
		}catch(Exception e) {
			throw new MTPException("Error while parsing value " + value + " from String to " + getParameter().getDatatype(), e);
		}
	}

	@Override
	public String toString() {
		return "BooleanParameterInstance [value=" + value
				+ ", parameter=" + parameter
				+ ", validationStatus=" + validationStatus
				+ "]";
	}
}
