package edu.uoc.pfc.j2ee.jalonsod.mtp.request;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.DoubleParameter;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Parameter;

/**
 * File: DoubleParameterInstance.java
 * Created: 2012-05-01
 * 
 * Holds a request parameter value of type <code>Double</code>.
 * 
 * @author Jos Alonso de Motta
 * @see DoubleParameter
*/
public class DoubleParameterInstance extends ParameterInstance {
	/**
	 * The value of the request parameter.
	 */
	Double value;

	public DoubleParameterInstance(Parameter parameter) {
		super(parameter);
		setValue(null);
	}

	@Override
	public Double getValue() {
		return value;
	}

	@Override
	public void setValue(Object value) {
		setValue((Double)value);
	}

	/**
	 * The setter of the value received as same datatype as the parameterInstance.
	 * 
	 * @param value the value to set.
	 */
	public void setValue(Double value) {
		this.value = value;
	}

	@Override
	public Double getDefaultValue() {
		return (Double)getParameter().getDefaultValue();
	}

	@Override
	public void setStringValue(String value) throws MTPException {
		try{
			if(value!=null && !value.equals("")){
				setValue(Double.parseDouble(value));
			}else{
				setValueAsDefault();
			}
		}catch(Exception e) {
			throw new MTPException("Error while parsing value " + value + " from String to " + getParameter().getDatatype(), e);
		}
	}

	@Override
	public String toString() {
		return "DoubleParameterInstance [value=" + value
				+ ", parameter=" + parameter
				+ ", validationStatus=" + validationStatus
				+ "]";
	}
}
