package edu.uoc.pfc.j2ee.jalonsod.mtp.request.taglib;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.BodyContent;
import javax.servlet.jsp.tagext.BodyTagSupport;

import edu.uoc.pfc.j2ee.jalonsod.mtp.helper.ContextFactory;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: SessionAttribute.java
 * Created: 2012-05-15
 * 
 * Support class for getSessionAttribute tag. Reads an attribute from the session context and stores
 * it in the page context.
 * 
 * @author Jos Alonso de Motta
 */
public class GetSessionAttribute extends BodyTagSupport {
	private static final long serialVersionUID = 1L;
	
	private String attribute;

	@Override
	public int doStartTag() throws JspException{
		Object attributeObject = null;
		try {
			RequestData requestData = ContextFactory.getRequestData(pageContext.getRequest());
			if(requestData!=null){
				attributeObject = requestData.getSessionAttribute(attribute);
			}
			pageContext.setAttribute(Constants.MTP_TAGLIB_VARIABLE_SESSION_ATTRIBUTE, attributeObject, PageContext.PAGE_SCOPE);
		} catch (Exception e) {
			throw new JspTagException("doStartTag: " + e.getMessage(), e);
		}
		return EVAL_BODY_BUFFERED;
	}

	@Override
	public int doAfterBody() throws JspTagException{
		BodyContent bodyContent = getBodyContent();
		try {
			bodyContent.writeOut(getPreviousOut());
		} catch (IOException e) {
			throw new JspTagException("doAfterBody: " + e.getMessage(), e);
		}
		bodyContent.clearBody();
		return SKIP_BODY;
	}

	public String getAttribute() {
		return attribute;
	}

	public void setAttribute(String attribute) {
		this.attribute = attribute;
	}
}
