package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Id;

/**
 * File: Actividad.java
 * Created: 2012-06-07
 * 
 * Contiene una actividad.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "Actividad")
public class Actividad {
	private int idActividad;
	private String nombre;
	private String descripcionLarga;
	private String requiereValidar;
	private Double cuotaEstandar;
	private Integer plazasDisponibles;
	private String paraAlumnos;
	private String paraPadres;
	private List<PeriodoActividad> periodos;

	/**
	 * Constructor vaco para Hibernate.
	 */
	public Actividad() {
	}

	/**
	 * Crea una nueva actividad, pasando todos los valores, excepto el identificador que lo crea la
	 * base de datos.
	 * 
	 * @param nombre            Nombre de la actividad.
	 * @param descripcionLarga  Descripcin larga de la actividad.
	 * @param requiereValidar   Indica si requiere validacin o no.
	 *                          Ver ContantesNegocio.ACTIVIDAD_*_REQUIERE_VALIDAR.
	 * @param cuotaEstandar     Cuota estndar de la actividad. Si el periodo no tiene cuota, se usa
	 *                          la estndar de la actividad.
	 * @param plazasDisponibles Nmero de plazas disponibles de la actividad.
	 * @param paraAlumnos       Indica si la actividad se realiza para alumnos.
	 * @param paraPadres        Indica si la actividad se realiza para padres.
	 */
	public Actividad(String nombre, String descripcionLarga,
			String requiereValidar, Double cuotaEstandar,
			Integer plazasDisponibles, String paraAlumnos, String paraPadres) {
		this.nombre = nombre;
		this.descripcionLarga = descripcionLarga;
		this.requiereValidar = requiereValidar;
		this.cuotaEstandar = cuotaEstandar;
		this.plazasDisponibles = plazasDisponibles;
		this.paraAlumnos = paraAlumnos;
		this.paraPadres = paraPadres;
	}

	// getters & setters
	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	public int getIdActividad() {
		return idActividad;
	}

	public void setIdActividad(int idActividad) {
		this.idActividad = idActividad;
	}

	public String getNombre() {
		return nombre;
	}

	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public String getDescripcionLarga() {
		return descripcionLarga;
	}

	public void setDescripcionLarga(String descripcionLarga) {
		this.descripcionLarga = descripcionLarga;
	}

	public String getRequiereValidar() {
		return requiereValidar;
	}

	public void setRequiereValidar(String requiereValidar) {
		this.requiereValidar = requiereValidar;
	}

	public Double getCuotaEstandar() {
		return cuotaEstandar;
	}

	public void setCuotaEstandar(Double cuotaEstandar) {
		this.cuotaEstandar = cuotaEstandar;
	}

	public Integer getPlazasDisponibles() {
		return plazasDisponibles;
	}

	public void setPlazasDisponibles(Integer plazasDisponibles) {
		this.plazasDisponibles = plazasDisponibles;
	}

	public String getParaAlumnos() {
		return paraAlumnos;
	}

	public void setParaAlumnos(String paraAlumnos) {
		this.paraAlumnos = paraAlumnos;
	}

	public String getParaPadres() {
		return paraPadres;
	}

	public void setParaPadres(String paraPadres) {
		this.paraPadres = paraPadres;
	}

	@OneToMany(mappedBy="idActividad", cascade={CascadeType.ALL})
	public List<PeriodoActividad> getPeriodos() {
		return periodos;
	}

	public void setPeriodos(List<PeriodoActividad> periodos) {
		this.periodos = periodos;
	}
}
