package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import java.util.Date;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Table;
import javax.persistence.Id;

/**
 * File: SolicitudAlumno.java
 * Created: 2012-05-25
 * 
 * Contiene los datos de un alumno de una solicitud para hacerse socio.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "SolicitudAlumno")
public class SolicitudAlumno {
	private Integer idSolAlumno;
	private String usuario;
	private String nombre;
	private String apellidos;
	private String curso;
	private Date fechaNacimiento;
	
	/**
	 * Constructor vaco para Hibernate.
	 */
	public SolicitudAlumno() {
	}
	
	/**
 	 * Crea un alumno dentro de una solicitud para hacerse socio.
 	 * 
	 * @param usuario         Identificador de socio asociado al alumno.
	 * @param nombre          Nombre del alumno.
	 * @param apellidos       Apellidos del alumno.
	 * @param curso           Curso del alumno.
	 * @param fechaNacimiento Fecha de nacimiento del alumno.
	 */
	public SolicitudAlumno(String usuario, String nombre,
			String apellidos, String curso, Date fechaNacimiento) {
		this.usuario = usuario;
		this.nombre = nombre;
		this.apellidos = apellidos;
		this.curso = curso;
		this.fechaNacimiento = fechaNacimiento;
	}

	// getters & setters
	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	public Integer getIdSolAlumno() {
		return idSolAlumno;
	}

	public void setIdSolAlumno(Integer idSolAlumno) {
		this.idSolAlumno = idSolAlumno;
	}

	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public String getNombre() {
		return nombre;
	}

	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public String getApellidos() {
		return apellidos;
	}

	public void setApellidos(String apellidos) {
		this.apellidos = apellidos;
	}

	public String getCurso() {
		return curso;
	}

	public void setCurso(String curso) {
		this.curso = curso;
	}

	public Date getFechaNacimiento() {
		return fechaNacimiento;
	}

	public void setFechaNacimiento(Date fechaNacimiento) {
		this.fechaNacimiento = fechaNacimiento;
	}
}
