package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Table;
import javax.persistence.Id;

/**
 * File: SolicitudPadre.java
 * Created: 2012-05-25
 * 
 * Contiene los datos de un padre/madre/tutor de una solicitud para hacerse socio.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "SolicitudPadre")
public class SolicitudPadre {
	private Integer idSolPadre;
	private String usuario;
	private String nombre;
	private String apellidos;
	private String documento;
	private String email;
	private String telefonos;
	
	/**
	 * Constructor vaco para Hibernate.
	 */
	public SolicitudPadre() {
	}
	
	/**
	 * Crea un padre/madre/tutor dentro de una solicitud para hacerse socio.
	 * 
	 * @param usuario   Identificador de socio asociado al padre/madre/tutor.
 	 * @param nombre    Nombre del padre/madre/tutor.
	 * @param apellidos Apellidos del padre/madre/tutor.
	 * @param documento Nmero de documento de identificacin del padre/madre/tutor.
	 * @param email     Direccin de email del padre/madre/tutor.
	 * @param telefonos Telfonos de contacto del padre/madre/tutor.
	 */
	public SolicitudPadre(String usuario, String nombre,
			String apellidos, String documento, String email, String telefonos) {
		this.usuario = usuario;
		this.nombre = nombre;
		this.apellidos = apellidos;
		this.documento = documento;
		this.email = email;
		this.telefonos = telefonos;
	}

	// getters & setters
	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	public Integer getIdSolPadre() {
		return idSolPadre;
	}

	public void setIdSolPadre(Integer idSolPadre) {
		this.idSolPadre = idSolPadre;
	}

	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public String getNombre() {
		return nombre;
	}

	public void setNombre(String nombre) {
		this.nombre = nombre;
	}

	public String getApellidos() {
		return apellidos;
	}

	public void setApellidos(String apellidos) {
		this.apellidos = apellidos;
	}

	public String getDocumento() {
		return documento;
	}

	public void setDocumento(String documento) {
		this.documento = documento;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getTelefonos() {
		return telefonos;
	}

	public void setTelefonos(String telefonos) {
		this.telefonos = telefonos;
	}
}
