package edu.uoc.pfc.j2ee.jalonsod.ampa.beans;

import java.util.Date;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Entity;
import javax.persistence.Table;
import javax.persistence.Id;
import javax.persistence.OneToMany;

/**
 * File: SolicitudSocio.java
 * Created: 2012-05-25
 * 
 * Contiene una solicitud para hacerse socio.
 * Se utiliza como transfer object y como entity class para integracin con Hibernate.
 * 
 * @author Jos Alonso de Motta
 */
@Entity
@Table (name = "SolicitudSocio")
public class SolicitudSocio {
	private String usuario;
	private String password;
	private String direccion;
	private Date fechaSolicitud;
	private List<SolicitudPadre> padres;
	private List<SolicitudAlumno> alumnos;
	
	/**
	 * Constructor vaco para Hibernate.
	 */
	public SolicitudSocio() {
	}
	
	/**
	 * Crea una nueva solicitud para hacerse socio.
	 * 
	 * @param usuario        Identificador nico de usuario para el acceso al sistema.
	 * @param password       Password del usuario.
	 * @param direccion      Direccin del socio.
	 * @param fechaSolicitud Fecha de solicitud de incorporacin como socio.
	 * @param padres         Lista de padres de la ficha de socio.
	 * @param alumnos        Lista de alumnos de la ficha de socio.
	 */
	public SolicitudSocio(String usuario, String password, String direccion,
			List<SolicitudPadre> padres, List<SolicitudAlumno> alumnos) {
		this.usuario = usuario;
		this.password = password;
		this.direccion = direccion;
		this.padres = padres;
		this.alumnos = alumnos;
	}
	
	// getters & setters
	@Id
	public String getUsuario() {
		return usuario;
	}
	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}
	
	public String getPassword() {
		return password;
	}
	public void setPassword(String password) {
		this.password = password;
	}

	public String getDireccion() {
		return direccion;
	}

	public void setDireccion(String direccion) {
		this.direccion = direccion;
	}

	public Date getFechaSolicitud() {
		return fechaSolicitud;
	}

	public void setFechaSolicitud(Date fechaSolicitud) {
		this.fechaSolicitud = fechaSolicitud;
	}

	@OneToMany(mappedBy="usuario", cascade={CascadeType.ALL})
	public List<SolicitudPadre> getPadres() {
		return padres;
	}

	public void setPadres(List<SolicitudPadre> padres) {
		this.padres = padres;
	}

	@OneToMany(mappedBy="usuario", cascade={CascadeType.ALL})
	public List<SolicitudAlumno> getAlumnos() {
		return alumnos;
	}

	public void setAlumnos(List<SolicitudAlumno> alumnos) {
		this.alumnos = alumnos;
	}
}
