package edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS;

import java.util.List;
import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Actividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PeriodoActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.ActividadBO;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO.BusinessObject;
import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPUtils;

/**
 * File: ActividadesAS.java
 * Created: 2012-06-08
 * 
 * Fachada de la capa de negocio para funciones relacionadas con las actividades.
 * 
 * @author Jos Alonso de Motta
 */
public class ActividadesAS extends BusinessObject {
	private final static Logger logger = Logger.getLogger(MTPUtils.getPackageName());

	/**
	 * Obtiene una actividad en base a su identificador.
	 * 
	 * @param idActividad Identificador de actividad a buscar.
	 * @return Actividad encontrada o null si no se encuentra o hay algn error.
	 */
	public Actividad getActividad(int idActividad){
		Actividad result = null;
		try {
			ActividadBO actividadBO = new ActividadBO();
			session.getTransaction().begin();
			result = actividadBO.getActividad(idActividad);
			session.getTransaction().commit();
		} catch (Exception e) {
			logger.warning("Error obteniendo actividad por id. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
		}
		return result;
	}

	/**
	 * Obtiene la lista de actividades que tienen algn periodo activo (no pasado).
	 * 
	 * @return Relacin de actividades con algn periodo activo (no pasado). Si no hay, devuelve una
	 *         lista vaca, y si hay algn error devuelve null.
	 */
	public List<Actividad> getActividadesActivas(){
		try {
			session.getTransaction().begin();
			List<Actividad> actividadesActivas = (new ActividadBO()).getActividadesActivas();
			session.getTransaction().commit();
			return actividadesActivas;
		} catch (Exception e) {
			logger.warning("Error obteniendo lista de actividades activas. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return null;
		}
	}
	
	/**
	 * Obtiene la lista de periodos activos para una actividad dada.
	 * 
	 * @param idActividad Identificador de la actividad a obtener sus periodos.
	 * @return            Lista de periodos activos de la actividad. Si no hay, devuelve una lista
	 *                    vaca, y si hay algn error devuelve null.
	 */
	public List<PeriodoActividad> getPeriodosActivos(int idActividad){
		try {
			session.getTransaction().begin();
			List<PeriodoActividad> periodosActivos = (new ActividadBO()).getPeriodosActivos(idActividad);
			session.getTransaction().commit();
			return periodosActivos;
		} catch (Exception e) {
			logger.warning("Error obteniendo lista de periodos activos de una actividad. Se hace rollback.");
			e.printStackTrace();
			session.getTransaction().rollback();
			return null;
		}
	}
}
