package edu.uoc.pfc.j2ee.jalonsod.ampa.business.BO;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Usuario;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;

/**
 * File: UsuarioBO.java
 * Created: 2012-06-01
 * 
 * Objeto de negocio para las operaciones relacionadas con usuarios y sus derivados.  
 * 
 * @author Jos Alonso de Motta
 */
public class UsuarioBO extends BusinessObject {
	
	/**
	 * Comprueba si existe un usuario en la base de datos.
	 * 
	 * @param usuarioCheck Usuario/password a comprobar.
	 * @return LOGIN_ADMIN/LOGIN_SOCIO si se identific correctamente, LOGIN_BADUSER si el usuario
	 * no se encontr o LOGIN_BADPASSWORD si la password es incorrecta.
	 */
	public int comprobarUsuario(Usuario usuarioCheck) {
		Usuario usuarioBD = getUsuario(usuarioCheck.getUsuario());
		if(usuarioBD!=null){
			if(usuarioCheck.getPassword().equals(usuarioBD.getPassword())){
				// Es usuario, comprobar si es administrador o socio.
				if(usuarioBD.getTipo().equals(ConstantesNegocio.USUARIO_ADMINISTRADOR)){
					return ConstantesNegocio.LOGIN_ADMIN;
				}else if (usuarioBD.getTipo().equals(ConstantesNegocio.USUARIO_SOCIO)){
					return ConstantesNegocio.LOGIN_SOCIO;
				}else{
					return ConstantesNegocio.LOGIN_ERROR;
				}
			}else{
				return ConstantesNegocio.LOGIN_BADPASSWORD;
			}
		}else{
			return ConstantesNegocio.LOGIN_BADUSER;
		}
	}
	/**
	 * Carga de la base de datos un usuario en base al identificador.
	 *  
	 * @param usuario Identificador de socio de la solicitud.
	 * @return        Usuario o null si no existe.
	 */
	public Usuario getUsuario(String usuario){
		return (Usuario)session.get(Usuario.class, usuario);
	}
}
