package edu.uoc.pfc.j2ee.jalonsod.ampa.business;

import java.util.Date;

/**
 * File: FuncionesValidacion.java
 * Created: 2012-06-11
 * 
 * Funciones para validar valores correctos.
 * 
 * @author Jos Alonso de Motta
 */
public class FuncionesValidacion {

	/**
	 * Comprueba que una direccin de email es correcta.
	 * 
	 * @param email Direccin de email a validar.
	 * @return      true si la direccin es correcta, false en caso contrario.
	 */
	public static boolean validarEMail(String email){
		return (email.matches("[a-zA-Z0-9_.]+@[a-zA-Z0-9_.]+.[a-zA-Z0-9_.]+"));
	}

	/**
	 * Comprueba que una fecha dada es anterior a hoy.
	 * 
	 * @param fecha Fecha a comprobar.
	 * @return      true si la fecha es anterior a hoy, false en caso contrario.
	 */
	public static boolean validarFechaPasada(Date fecha){
		return fecha.before(new java.util.Date());
	}
	
	/**
	 * Comprueba que un nmero en coma flotante dado es positivo (mayor que cero).
	 * 
	 * @param valor Nmero a comprobar.
	 * @return      true si es positivo (mayor que cero), false en caso contrario.
	 */
	public static boolean validarPositivo(Double valor){
		return (valor>0);
	}
	
	/**
	 * Comprueba que un nmero entero dado es positivo (mayor que cero).
	 * 
	 * @param valor Nmero a comprobar.
	 * @return      true si es positivo (mayor que cero), false en caso contrario.
	 */
	public static boolean validarPositivo(Integer valor){
		return (valor>0);
	}
	
	/**
	 * Comprueba que el valor lgico indicado es verdadero.
	 * 
	 * @param valor Valor a comprobar.
	 * @return      true si el parmetro es true, false si es false.
	 */
	public static boolean validarVerdadero(Boolean valor){
		return (valor==true);
	}

	/**
	 * Comprueba que el valor lgico indicado es falso.
	 * 
	 * @param valor Valor a comprobar.
	 * @return      true si el parmetro es false, false si es true.
	 */
	public static boolean validarFalso(Boolean valor){
		return (valor!=true);
	}

	/**
	 * Para comprobar la funcin de validacin de email con distintas expresiones.
	 * 
	 * @param args No se utiliza.
	 */
	public static void main(String[] args){
		String[] emailsPrueba = {"a@b.c", "@b.c", "a@b", "a@x.", "a@.x", "a.b@c.d", "user@example.com"};
		for(int i=0;i<emailsPrueba.length;i++){
			System.out.println("Validando email " + emailsPrueba[i] + ": " + validarEMail(emailsPrueba[i]));
		}
	}
}
