package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import java.util.Date;
import java.util.ArrayList;
import java.util.List;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Alumno;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Padre;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SeguridadAS;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SociosAS;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: FichaSocioModel.java
 * Created: 2012-06-09
 * 
 * Modelo de presentacin para mantenimiento de la ficha de socio del usuario.  
 * 
 * @author Jos Alonso de Motta
 */
public class FichaSocioModel {
	// Parmetros de entrada
	private String usuario;
	private String password;
	private String direccion;
	private Integer idPadre1;
	private String nombrePadre1;
	private String apellidosPadre1;
	private String documentoPadre1;
	private String emailPadre1;
	private String telefonosPadre1;
	private Integer idPadre2;
	private String nombrePadre2;
	private String apellidosPadre2;
	private String documentoPadre2;
	private String emailPadre2;
	private String telefonosPadre2;
	private Integer idAlumno1;
	private String nombreAlumno1;
	private String apellidosAlumno1;
	private String cursoAlumno1;
	private Date fechaNacimientoAlumno1;
	private Integer idAlumno2;
	private String nombreAlumno2;
	private String apellidosAlumno2;
	private String cursoAlumno2;
	private Date fechaNacimientoAlumno2;
	private Integer idAlumno3;
	private String nombreAlumno3;
	private String apellidosAlumno3;
	private String cursoAlumno3;
	private Date fechaNacimientoAlumno3;
	private Integer idAlumno4;
	private String nombreAlumno4;
	private String apellidosAlumno4;
	private String cursoAlumno4;
	private Date fechaNacimientoAlumno4;
	private Integer idAlumno5;
	private String nombreAlumno5;
	private String apellidosAlumno5;
	private String cursoAlumno5;
	private Date fechaNacimientoAlumno5;
	private Integer idAlumno6;
	private String nombreAlumno6;
	private String apellidosAlumno6;
	private String cursoAlumno6;
	private Date fechaNacimientoAlumno6;

	// Parmetros de entrada/salida
	private Integer numPadres;
	private Integer numAlumnos;
	// Parmetros de salida
	private Socio socio;
	private boolean resultado = false;
	private String operacion = null;
	private List<Padre> padres;
	private List<Alumno> alumnos;

	/**
	 * Accin para cargar los datos de la ficha de socio.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return OK
	 */
	public String runForm(RequestData requestData){
		// Refresca los datos del socio en base al nombre de usuario de la sesin
		socio = UtilesModelos.getSocio(requestData);
		socio = (Socio)(new SeguridadAS()).getUsuario(socio.getUsuario());
		loadFormData();
		return UtilesModelos.RESULT_OK;
	}
	
	/**
	 * Accin para registrar las modificaciones en la ficha de socios.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return OK si se enviaron los datos a actualizar, CANCEL si se solicit salir sin actualizar.
	 */
	public String runConfirm(RequestData requestData){
		// Refresca los datos del socio en base al nombre de usuario de la sesin
		socio = UtilesModelos.getSocio(requestData);
		socio = (Socio)(new SeguridadAS()).getUsuario(socio.getUsuario());
		String tipoSubmit = requestData.getRequestParameter(UtilesModelos.REQUEST_SUBMIT_PARAMETER);
		if(tipoSubmit.equals(UtilesModelos.REQUEST_SUBMIT_CANCEL)){
			operacion = null;
			return UtilesModelos.RESULT_CANCEL;
		}else{
			operacion = UtilesModelos.OPERACION_UPDATE;
			resultado = true;
			// La clave del socio no puede haber cambiado
			if(socio.getUsuario().equals(usuario)){
				socio = new Socio(usuario, password, direccion, socio.getFechaSolicitud(), ConstantesNegocio.SOCIO_VALIDO_SI, getPadresForm(), getAlumnosForm());
				if ((new SociosAS()).actualizarSocio(socio)){
				}else{
					resultado = false;
				}
			}else{
				// No se puede actualizar la informacin de otro socio.
				resultado = false;
			}
			socio = (Socio)(new SeguridadAS()).getUsuario(usuario);
			// Actualiza en la sesin los datos del socio
			UtilesModelos.setSocio(requestData, socio);
			loadFormData();
			return UtilesModelos.RESULT_OK;
		}
	}
	
	/**
	 * Carga los datos de la ficha de socios.
	 * 
	 * @return true si se cargan los datos correctamente, false en caso contrario.
	 */
	private boolean loadFormData(){
		padres = (new SociosAS()).getPadres(socio);
		numPadres = padres.size();
		alumnos = (new SociosAS()).getAlumnos(socio);
		numAlumnos = alumnos.size();
		if(padres!=null && alumnos !=null ){
			return true;
		}else{
			return false;
		}
	}
	
	/**
	 * Carga en una lista los datos de los padres obtenidos de los parmetros recibidos en la peticin.
	 * 
	 * @return Lista con los datos de los padres.
	 */
	public List<Padre> getPadresForm(){
		List<Padre> padresForm = new ArrayList<Padre>();
		if(numPadres>=1){
			padresForm.add(new Padre(idPadre1, usuario, nombrePadre1, apellidosPadre1, documentoPadre1, emailPadre1, telefonosPadre1 ));
		}
		if(numPadres>=2){
			padresForm.add(new Padre(idPadre2, usuario, nombrePadre2, apellidosPadre2, documentoPadre2, emailPadre2, telefonosPadre2 ));
		}
		return padresForm;
	}
	
	/**
	 * Carga en una lista los datos de los padres obtenidos de los parmetros recibidos en la peticin.
	 * 
	 * @return Lista con los datos de los padres.
	 */
	public List<Alumno> getAlumnosForm(){
		List<Alumno> alumnosForm = new ArrayList<Alumno>();
		if(numAlumnos>=1){
			alumnosForm.add(new Alumno(idAlumno1, usuario, nombreAlumno1, apellidosAlumno1, cursoAlumno1, fechaNacimientoAlumno1));
		}
		if(numAlumnos>=2){
			alumnosForm.add(new Alumno(idAlumno2, usuario, nombreAlumno2, apellidosAlumno2, cursoAlumno2, fechaNacimientoAlumno2));
		}
		if(numAlumnos>=3){
			alumnosForm.add(new Alumno(idAlumno3, usuario, nombreAlumno3, apellidosAlumno3, cursoAlumno3, fechaNacimientoAlumno3));
		}
		if(numAlumnos>=4){
			alumnosForm.add(new Alumno(idAlumno4, usuario, nombreAlumno4, apellidosAlumno4, cursoAlumno4, fechaNacimientoAlumno4));
		}
		if(numAlumnos>=5){
			alumnosForm.add(new Alumno(idAlumno5, usuario, nombreAlumno5, apellidosAlumno5, cursoAlumno5, fechaNacimientoAlumno5));
		}
		if(numAlumnos>=6){
			alumnosForm.add(new Alumno(idAlumno6, usuario, nombreAlumno6, apellidosAlumno6, cursoAlumno6, fechaNacimientoAlumno6));
		}
		return alumnosForm;
	}

	// getters & setters
	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public String getDireccion() {
		return direccion;
	}

	public void setDireccion(String direccion) {
		this.direccion = direccion;
	}

	public Integer getIdPadre1() {
		return idPadre1;
	}

	public void setIdPadre1(Integer idPadre1) {
		this.idPadre1 = idPadre1;
	}

	public String getNombrePadre1() {
		return nombrePadre1;
	}

	public void setNombrePadre1(String nombrePadre1) {
		this.nombrePadre1 = nombrePadre1;
	}

	public String getApellidosPadre1() {
		return apellidosPadre1;
	}

	public void setApellidosPadre1(String apellidosPadre1) {
		this.apellidosPadre1 = apellidosPadre1;
	}

	public String getDocumentoPadre1() {
		return documentoPadre1;
	}

	public void setDocumentoPadre1(String documentoPadre1) {
		this.documentoPadre1 = documentoPadre1;
	}

	public String getEmailPadre1() {
		return emailPadre1;
	}

	public void setEmailPadre1(String emailPadre1) {
		this.emailPadre1 = emailPadre1;
	}

	public String getTelefonosPadre1() {
		return telefonosPadre1;
	}

	public void setTelefonosPadre1(String telefonosPadre1) {
		this.telefonosPadre1 = telefonosPadre1;
	}

	public Integer getIdPadre2() {
		return idPadre2;
	}

	public void setIdPadre2(Integer idPadre2) {
		this.idPadre2 = idPadre2;
	}

	public String getNombrePadre2() {
		return nombrePadre2;
	}

	public void setNombrePadre2(String nombrePadre2) {
		this.nombrePadre2 = nombrePadre2;
	}

	public String getApellidosPadre2() {
		return apellidosPadre2;
	}

	public void setApellidosPadre2(String apellidosPadre2) {
		this.apellidosPadre2 = apellidosPadre2;
	}

	public String getDocumentoPadre2() {
		return documentoPadre2;
	}

	public void setDocumentoPadre2(String documentoPadre2) {
		this.documentoPadre2 = documentoPadre2;
	}

	public String getEmailPadre2() {
		return emailPadre2;
	}

	public void setEmailPadre2(String emailPadre2) {
		this.emailPadre2 = emailPadre2;
	}

	public String getTelefonosPadre2() {
		return telefonosPadre2;
	}

	public void setTelefonosPadre2(String telefonosPadre2) {
		this.telefonosPadre2 = telefonosPadre2;
	}

	public Integer getIdAlumno1() {
		return idAlumno1;
	}

	public void setIdAlumno1(Integer idAlumno1) {
		this.idAlumno1 = idAlumno1;
	}

	public String getNombreAlumno1() {
		return nombreAlumno1;
	}

	public void setNombreAlumno1(String nombreAlumno1) {
		this.nombreAlumno1 = nombreAlumno1;
	}

	public String getApellidosAlumno1() {
		return apellidosAlumno1;
	}

	public void setApellidosAlumno1(String apellidosAlumno1) {
		this.apellidosAlumno1 = apellidosAlumno1;
	}

	public String getCursoAlumno1() {
		return cursoAlumno1;
	}

	public void setCursoAlumno1(String cursoAlumno1) {
		this.cursoAlumno1 = cursoAlumno1;
	}

	public Date getFechaNacimientoAlumno1() {
		return fechaNacimientoAlumno1;
	}

	public void setFechaNacimientoAlumno1(Date fechaNacimientoAlumno1) {
		this.fechaNacimientoAlumno1 = fechaNacimientoAlumno1;
	}

	public Integer getIdAlumno2() {
		return idAlumno2;
	}

	public void setIdAlumno2(Integer idAlumno2) {
		this.idAlumno2 = idAlumno2;
	}

	public String getNombreAlumno2() {
		return nombreAlumno2;
	}

	public void setNombreAlumno2(String nombreAlumno2) {
		this.nombreAlumno2 = nombreAlumno2;
	}

	public String getApellidosAlumno2() {
		return apellidosAlumno2;
	}

	public void setApellidosAlumno2(String apellidosAlumno2) {
		this.apellidosAlumno2 = apellidosAlumno2;
	}

	public String getCursoAlumno2() {
		return cursoAlumno2;
	}

	public void setCursoAlumno2(String cursoAlumno2) {
		this.cursoAlumno2 = cursoAlumno2;
	}

	public Date getFechaNacimientoAlumno2() {
		return fechaNacimientoAlumno2;
	}

	public void setFechaNacimientoAlumno2(Date fechaNacimientoAlumno2) {
		this.fechaNacimientoAlumno2 = fechaNacimientoAlumno2;
	}

	public Integer getIdAlumno3() {
		return idAlumno3;
	}

	public void setIdAlumno3(Integer idAlumno3) {
		this.idAlumno3 = idAlumno3;
	}

	public String getNombreAlumno3() {
		return nombreAlumno3;
	}

	public void setNombreAlumno3(String nombreAlumno3) {
		this.nombreAlumno3 = nombreAlumno3;
	}

	public String getApellidosAlumno3() {
		return apellidosAlumno3;
	}

	public void setApellidosAlumno3(String apellidosAlumno3) {
		this.apellidosAlumno3 = apellidosAlumno3;
	}

	public String getCursoAlumno3() {
		return cursoAlumno3;
	}

	public void setCursoAlumno3(String cursoAlumno3) {
		this.cursoAlumno3 = cursoAlumno3;
	}

	public Date getFechaNacimientoAlumno3() {
		return fechaNacimientoAlumno3;
	}

	public void setFechaNacimientoAlumno3(Date fechaNacimientoAlumno3) {
		this.fechaNacimientoAlumno3 = fechaNacimientoAlumno3;
	}

	public Integer getIdAlumno4() {
		return idAlumno4;
	}

	public void setIdAlumno4(Integer idAlumno4) {
		this.idAlumno4 = idAlumno4;
	}

	public String getNombreAlumno4() {
		return nombreAlumno4;
	}

	public void setNombreAlumno4(String nombreAlumno4) {
		this.nombreAlumno4 = nombreAlumno4;
	}

	public String getApellidosAlumno4() {
		return apellidosAlumno4;
	}

	public void setApellidosAlumno4(String apellidosAlumno4) {
		this.apellidosAlumno4 = apellidosAlumno4;
	}

	public String getCursoAlumno4() {
		return cursoAlumno4;
	}

	public void setCursoAlumno4(String cursoAlumno4) {
		this.cursoAlumno4 = cursoAlumno4;
	}

	public Date getFechaNacimientoAlumno4() {
		return fechaNacimientoAlumno4;
	}

	public void setFechaNacimientoAlumno4(Date fechaNacimientoAlumno4) {
		this.fechaNacimientoAlumno4 = fechaNacimientoAlumno4;
	}

	public Integer getIdAlumno5() {
		return idAlumno5;
	}

	public void setIdAlumno5(Integer idAlumno5) {
		this.idAlumno5 = idAlumno5;
	}

	public String getNombreAlumno5() {
		return nombreAlumno5;
	}

	public void setNombreAlumno5(String nombreAlumno5) {
		this.nombreAlumno5 = nombreAlumno5;
	}

	public String getApellidosAlumno5() {
		return apellidosAlumno5;
	}

	public void setApellidosAlumno5(String apellidosAlumno5) {
		this.apellidosAlumno5 = apellidosAlumno5;
	}

	public String getCursoAlumno5() {
		return cursoAlumno5;
	}

	public void setCursoAlumno5(String cursoAlumno5) {
		this.cursoAlumno5 = cursoAlumno5;
	}

	public Date getFechaNacimientoAlumno5() {
		return fechaNacimientoAlumno5;
	}

	public void setFechaNacimientoAlumno5(Date fechaNacimientoAlumno5) {
		this.fechaNacimientoAlumno5 = fechaNacimientoAlumno5;
	}

	public Integer getIdAlumno6() {
		return idAlumno6;
	}

	public void setIdAlumno6(Integer idAlumno6) {
		this.idAlumno6 = idAlumno6;
	}

	public String getNombreAlumno6() {
		return nombreAlumno6;
	}

	public void setNombreAlumno6(String nombreAlumno6) {
		this.nombreAlumno6 = nombreAlumno6;
	}

	public String getApellidosAlumno6() {
		return apellidosAlumno6;
	}

	public void setApellidosAlumno6(String apellidosAlumno6) {
		this.apellidosAlumno6 = apellidosAlumno6;
	}

	public String getCursoAlumno6() {
		return cursoAlumno6;
	}

	public void setCursoAlumno6(String cursoAlumno6) {
		this.cursoAlumno6 = cursoAlumno6;
	}

	public Date getFechaNacimientoAlumno6() {
		return fechaNacimientoAlumno6;
	}

	public void setFechaNacimientoAlumno6(Date fechaNacimientoAlumno6) {
		this.fechaNacimientoAlumno6 = fechaNacimientoAlumno6;
	}

	public Integer getNumPadres() {
		return numPadres;
	}

	public void setNumPadres(Integer numPadres) {
		this.numPadres = numPadres;
	}

	public Integer getNumAlumnos() {
		return numAlumnos;
	}

	public void setNumAlumnos(Integer numAlumnos) {
		this.numAlumnos = numAlumnos;
	}

	public Socio getSocio() {
		return socio;
	}

	public void setSocio(Socio socio) {
		this.socio = socio;
	}

	public boolean isResultado() {
		return resultado;
	}

	public void setResultado(boolean resultado) {
		this.resultado = resultado;
	}

	public String getOperacion() {
		return operacion;
	}

	public void setOperacion(String operacion) {
		this.operacion = operacion;
	}

	public List<Padre> getPadres() {
		return padres;
	}

	public void setPadres(List<Padre> padres) {
		this.padres = padres;
	}

	public List<Alumno> getAlumnos() {
		return alumnos;
	}

	public void setAlumnos(List<Alumno> alumnos) {
		this.alumnos = alumnos;
	}
}
