package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Actividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Alumno;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.AlumnoActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Padre;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PadreActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.PeriodoActividad;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.ActividadesAS;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SociosAS;
import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPUtils;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: InscripcionesModel.java
 * Created: 2012-06-06
 * 
 * Modelo de presentacin para inscripciones.  
 * 
 * @author Jos Alonso de Motta
 */
public class InscripcionesModel {
	private final static Logger logger = Logger.getLogger(MTPUtils.getPackageName());
	// Parmetros de entrada
	private Integer idActividad;
	private Integer idPadre;
	private Integer idAlumno;
	
	// Parmetros de salida
	// Para la lista de inscripciones
	private List<PadreActividad> inscripcionesPadres;
	private List<AlumnoActividad> inscripcionesAlumnos;
	private List<Actividad> actividadesActivas;
	private boolean resultado = false;
	private String operacion = null;
	// Para el form de alta
	private List<Padre> padres;
	private Integer numPadres;
	private List<Alumno> alumnos;
	private Integer numAlumnos;
	private Actividad actividad;
	private List<PeriodoActividad> periodos;
	
	// Variables de trabajo
	Socio socio = null;

	public InscripcionesModel(){
	}

	/**
	 * Accin para obtener el listado de inscripciones del socio.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return OK si se carga correctamente la lista de inscripciones, false en caso contrario.
	 */
	public String runList(RequestData requestData) {
		socio = UtilesModelos.getSocio(requestData);
		operacion = UtilesModelos.OPERACION_LIST;
		if(loadInscripciones()){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}

	/**
	 * Validacin de los parmetros de entrada para la accin de baja. Solo puede llegar uno de los
	 * dos valores idPadre o idAlumno.
	 * 
	 * @return OK si los parmetros son correctos, false en caso contrario.
	 */
	public boolean validateBaja(){
		// Solo puede llegar el idPadre o el idAlumno
		if((idPadre!=null && idAlumno!=null) || (idPadre==null && idAlumno==null)){
			return false;
		}
		return true;
	}

	/**
	 * Accin para la baja de una inscripcin de alumno o padre.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return OK si se carga correctamente la lista de inscripciones, false en caso contrario.
	 */
	public String runBaja(RequestData requestData) {
		socio = UtilesModelos.getSocio(requestData);
		operacion = UtilesModelos.OPERACION_DELETE;
		boolean result = false;
		if(idPadre!=null){
			result = (new SociosAS()).eliminarPadreActividad(socio.getUsuario(), idPadre, idActividad);
		}else{
			result = (new SociosAS()).eliminarAlumnoActividad(socio.getUsuario(), idAlumno, idActividad);
		}
		if(result){
			resultado=true;
		}else{
			resultado=false;
		}
		if(loadInscripciones()){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}

	/**
	 * Accin para cargar el formulario de alta de inscripciones a una actividad.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return OK si se carga correctamente el formulario de alta, false en caso contrario.
	 */
	public String runAltaForm(RequestData requestData){
		socio = UtilesModelos.getSocio(requestData);
		if(loadFormAlta()){
			return UtilesModelos.RESULT_OK;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}

	/**
	 * Accin para registrar el alta de inscripciones de padres y alumnos de un socio a una actividad.
	 * La propiedad operacion le indica a la vista el tipo de accin realizada.
	 * La propiedad resultado le indica a la vista si la accin se ha realizado correctamente.
	 * 
	 * @param requestData
	 * @return OK
	 */
	public String runAltaConfirm(RequestData requestData) {
		socio = UtilesModelos.getSocio(requestData);
		String tipoSubmit = requestData.getRequestParameter(UtilesModelos.REQUEST_SUBMIT_PARAMETER);
		if(tipoSubmit.equals(UtilesModelos.REQUEST_SUBMIT_CANCEL)){
			loadInscripciones();
			operacion = null;
			return UtilesModelos.RESULT_CANCEL;
		}else{
			operacion = UtilesModelos.OPERACION_INSERT;
			resultado = true;
			ArrayList<Integer> idPadres = new ArrayList<Integer>();
			ArrayList<Integer> idAlumnos = new ArrayList<Integer>();
			for(int i=1; i<=numPadres;i++){
				String sidPadre = requestData.getRequestParameter("idPadre"+i);
				if(sidPadre!=null){
					try {
						Integer idPadre = Integer.parseInt(sidPadre);
						idPadres.add(idPadre);
					} catch (NumberFormatException e) {
						resultado=false;
						logger.warning("Error conviritiendo idPadre " + sidPadre + " a Integer.");
						e.printStackTrace();
						break;
					}
				}
			}
			for(int i=1; i<=numAlumnos;i++){
				String sidAlumno = requestData.getRequestParameter("idAlumno"+i);
				if(sidAlumno!=null){
					try {
						Integer idAlumno = Integer.parseInt(sidAlumno);
						idAlumnos.add(idAlumno);
					} catch (NumberFormatException e) {
						resultado=false;
						logger.warning("Error conviritiendo idAlumnno " + sidAlumno + " a Integer.");
						e.printStackTrace();
						break;
					}
				}
			}
			if(resultado){
				resultado = (new SociosAS()).crearInscripciones(idActividad, idPadres, idAlumnos);
			}
			loadInscripciones();
			return UtilesModelos.RESULT_OK;
		}
	}

	/**
	 * Carga los datos para la vista del formulario de alta.
	 * 
	 * @return true si se cargan los datos correctamente, false en caso contrario.
	 */
	private boolean loadFormAlta(){
		padres = (new SociosAS()).getPadres(socio);
		numPadres = padres.size();
		alumnos = (new SociosAS()).getAlumnos(socio);
		numAlumnos = alumnos.size();
		actividad = (new ActividadesAS()).getActividad(idActividad);
		periodos = (new ActividadesAS()).getPeriodosActivos(idActividad);
		if(padres!=null && alumnos!=null){
			return true;
		}else{
			return false;
		}
	}

	/**
	 * Carga los datos para la vista con la lista de inscripciones.
	 * 
	 * @return true si se cargan los datos correctamente, false en caso contrario.
	 */
	public boolean loadInscripciones(){
		setInscripcionesPadres((new SociosAS()).getInscripcionesPadres(socio));
		setInscripcionesAlumnos((new SociosAS()).getInscripcionesAlumnos(socio));
		setActividadesActivas((new ActividadesAS()).getActividadesActivas());
		if(getInscripcionesAlumnos()==null ||getInscripcionesPadres()==null){
			return false;
		}else{
			return true;
		}
	}

	// getters & setters
	public List<PadreActividad> getInscripcionesPadres() {
		return inscripcionesPadres;
	}

	public void setInscripcionesPadres(List<PadreActividad> inscripcionesPadres) {
		this.inscripcionesPadres = inscripcionesPadres;
	}

	public List<AlumnoActividad> getInscripcionesAlumnos() {
		return inscripcionesAlumnos;
	}

	public void setInscripcionesAlumnos(List<AlumnoActividad> inscripcionesAlumnos) {
		this.inscripcionesAlumnos = inscripcionesAlumnos;
	}

	public Integer getIdActividad() {
		return idActividad;
	}

	public void setIdActividad(Integer idActividad) {
		this.idActividad = idActividad;
	}

	public Integer getIdPadre() {
		return idPadre;
	}

	public void setIdPadre(Integer idPadre) {
		this.idPadre = idPadre;
	}

	public Integer getIdAlumno() {
		return idAlumno;
	}

	public void setIdAlumno(Integer idAlumno) {
		this.idAlumno = idAlumno;
	}

	public boolean isResultado() {
		return resultado;
	}

	public void setResultado(boolean resultado) {
		this.resultado = resultado;
	}

	public String getOperacion() {
		return operacion;
	}

	public void setOperacion(String operacion) {
		this.operacion = operacion;
	}

	public List<Actividad> getActividadesActivas() {
		return actividadesActivas;
	}

	public void setActividadesActivas(List<Actividad> actividadesActivas) {
		this.actividadesActivas = actividadesActivas;
	}

	public List<Padre> getPadres() {
		return padres;
	}

	public void setPadres(List<Padre> padres) {
		this.padres = padres;
	}

	public List<Alumno> getAlumnos() {
		return alumnos;
	}

	public void setAlumnos(List<Alumno> alumnos) {
		this.alumnos = alumnos;
	}

	public Actividad getActividad() {
		return actividad;
	}

	public void setActividad(Actividad actividad) {
		this.actividad = actividad;
	}

	public Integer getNumPadres() {
		return numPadres;
	}

	public void setNumPadres(Integer numPadres) {
		this.numPadres = numPadres;
	}

	public Integer getNumAlumnos() {
		return numAlumnos;
	}

	public void setNumAlumnos(Integer numAlumnos) {
		this.numAlumnos = numAlumnos;
	}

	public List<PeriodoActividad> getPeriodos() {
		return periodos;
	}

	public void setPeriodos(List<PeriodoActividad> periodos) {
		this.periodos = periodos;
	}
}
