package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Administrador;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Usuario;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SeguridadAS;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SociosAS;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.AS.SolicitudAltaAS;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: LoginModel.java
 * Created: 2012-06-01
 * 
 * Modelo de presentacin para solicitud de alta (carga del formulario y confirmacin).  
 * 
 * @author Jos Alonso de Motta
 */
public class LoginModel {
	// Parmetros de entrada
	private String usuario;
	private String password;

	// Parmetros de salida
	private int respuesta;		// Indica el tipo de usuario o el tipo de error obtenido en el login.
	private int numeroSolicitudesPendientes = -1;
	private Socio socio;
	
	/**
	 * Constructor por defecto. Inicializa el indicador de estado de conexin.
	 */
	public LoginModel(){
		respuesta = ConstantesNegocio.LOGIN_ERROR;
	}
	
	/**
	 * Accin para hacer login.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return IS_SOCIO si es un socio vlido, IS_ADMINISTRADOR si es un administrador vlido,
	 *         ERROR en caso contrario.
	 */
	public String runLogin(RequestData requestData){
		Usuario checkUser = new Usuario(usuario, password, null);
		setRespuesta((new SeguridadAS()).login(checkUser));
		if(respuesta==ConstantesNegocio.LOGIN_ADMIN){
			UtilesModelos.setAdministrador(requestData, (Administrador)(new SeguridadAS()).getUsuario(usuario));
			setNumeroSolicitudesPendientes((new SolicitudAltaAS()).getNumSolicitudesPendientes());
			return UtilesModelos.RESULT_IS_ADMINISTRADOR;
		}else if(respuesta==ConstantesNegocio.LOGIN_SOCIO){
			socio = (new SociosAS()).getSocio(usuario);
			UtilesModelos.setSocio(requestData, (Socio)(new SeguridadAS()).getUsuario(usuario));
			return UtilesModelos.RESULT_IS_SOCIO;
		}else{
			return UtilesModelos.RESULT_ERROR;
		}
	}
	
	/**
	 * Accin para hacer logout.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return
	 */
	public String runLogout(RequestData requestData){
		requestData.logoutSession();
		respuesta = ConstantesNegocio.LOGIN_LOGOUT;
		return UtilesModelos.RESULT_OK;
	}

	// getters & setters
	public String getUsuario() {
		return usuario;
	}

	public void setUsuario(String usuario) {
		this.usuario = usuario;
	}

	public String getPassword() {
		return password;
	}

	public void setPassword(String password) {
		this.password = password;
	}

	public int getRespuesta() {
		return respuesta;
	}

	public void setRespuesta(int respuesta) {
		this.respuesta = respuesta;
	}

	public int getNumeroSolicitudesPendientes() {
		return numeroSolicitudesPendientes;
	}

	public void setNumeroSolicitudesPendientes(int numeroSolicitudesPendientes) {
		this.numeroSolicitudesPendientes = numeroSolicitudesPendientes;
	}

	public Socio getSocio() {
		return socio;
	}

	public void setSocio(Socio socio) {
		this.socio = socio;
	}
}
