package edu.uoc.pfc.j2ee.jalonsod.ampa.presentation.models;

import java.util.Hashtable;

import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Administrador;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Socio;
import edu.uoc.pfc.j2ee.jalonsod.ampa.beans.Usuario;
import edu.uoc.pfc.j2ee.jalonsod.ampa.business.ConstantesNegocio;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Role;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: UtilesModelos.java
 * Created: 2012-06-01
 * 
 * Contiene constantes y funciones de uso comn para los modelos.  
 * 
 * @author Jos Alonso de Motta
 */
public class UtilesModelos {
	public static final String SESSION_ATTRIBUTE_USER = "usuario";

	public static final String RESULT_OK = "OK";
	public static final String RESULT_ERROR = "ERROR";
	public static final String RESULT_CANCEL = "CANCEL";
	public static final String RESULT_IS_ADMINISTRADOR = "ADMIN";
	public static final String RESULT_IS_SOCIO = "SOCIO";
	public static final String RESULT_IS_NOUSER = "NOUSER";
	
	public static final String OPERACION_SELECT = "SELECT";
	public static final String OPERACION_DELETE = "DELETE";
	public static final String OPERACION_UPDATE = "UPDATE";
	public static final String OPERACION_RENOVAR = "RENOVAR";
	public static final String OPERACION_INSERT = "INSERT";
	public static final String OPERACION_LIST = "LIST";
	
	public static final String REQUEST_SUBMIT_PARAMETER = "Submit";
	public static final String REQUEST_SUBMIT_CANCEL = "Cancel";
	
	public static final int MAX_PADRES_POR_SOCIO = 2;
	public static final int MAX_ALUMNOS_POR_SOCIO = 6;

	/**
	 * Fija el socio indicado como usuario de la sesin actual.
	 * 
	 * @param requestData   Informacin sobre el request, con la sesin.
	 * @param socio       Socio a registrar como usuario de la sesin.
	 */
	public static void setSocio(RequestData requestData, Socio socio){
		requestData.setSessionAttribute(SESSION_ATTRIBUTE_USER, socio);
		setRolSocio(requestData);
	}
	
	/**
	 * Fija el administrador indicado como usuario de la sesin actual.
	 * 
	 * @param requestData   Informacin sobre el request, con la sesin.
	 * @param administrador Adiministrador a registrar como usuario de la sesin.
	 */
	public static void setAdministrador(RequestData requestData, Administrador administrador){
		requestData.setSessionAttribute(SESSION_ATTRIBUTE_USER, administrador);
		setRolAdministrador(requestData);
	}

	/**
	 * Obtiene el usuario de la sesin.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin. 
	 * @return            Usuario obtenido de la sesin.
	 */
	public static Usuario getUsuario(RequestData requestData){
		Usuario usuario = (Usuario)requestData.getSessionAttribute(SESSION_ATTRIBUTE_USER);
		return usuario;
	}
	
	/**
	 * Obtiene el administrador asociado a la sesin.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return            Administrador obtenido de la sesin.
	 */
	public static Administrador getAdministrador(RequestData requestData){
		return (Administrador)getUsuario(requestData);
	}
	
	/**
	 * Obtiene el socio asociado a la sesin.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @return            Socio obtenido de la sesin.
	 */
	public static Socio getSocio(RequestData requestData){
		return (Socio)getUsuario(requestData);
	}
	
	/**
	 * Fija en la sesin el rol de administrador.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 */
	public static void setRolAdministrador(RequestData requestData){
		requestData.setRoles(getRol(requestData, ConstantesNegocio.ROL_ADMINISTRADOR));
	}

	/**
	 * Fija en la sesin el rol de socio.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 */
	public static void setRolSocio(RequestData requestData){
		requestData.setRoles(getRol(requestData, ConstantesNegocio.ROL_SOCIO));
	}
	
	/**
	 * Crea un Hashtable con el rol indicado.
	 * 
	 * @param requestData Informacin sobre el request, con la sesin.
	 * @param roleName    Nombre de rol a generar.
	 * @return            Hashtable con el rol indicado.
	 */
	private static Hashtable<String, Role> getRol(RequestData requestData, String roleName){
		Hashtable<String, Role> roles = new Hashtable<String, Role>();
		roles.put(roleName, requestData.getConfigurator().getRoleByKey(roleName));
		return roles;
	}
}
