package edu.uoc.pfc.j2ee.jalonsod.mtp;

/**
 * File: MTPException.java
 * Created: 2012-04-28
 * 
 * Encapsulates errors in the framework.
 *   
 * @author Jos Alonso de Motta
 */
public class MTPException extends Exception {
	private static final long serialVersionUID = 1L;
	
	/**
	 * The request has no error.
	 */
	public static final int MTP_EXCEPTION_NOERROR = 0;
	
	/**
	 * The request has thrown the exception creating the <code>requestData</code> object.
	 */
	public static final int MTP_EXCEPTION_REQUEST_DATA = 1;
	
	/**
	 * The request has thrown the exception during the <code>modelMapper</code> stage of the request.
	 */
	public static final int MTP_EXCEPTION_MODEL_MAPPER = 2;
	
	/**
	 * The request has thrown the exception during the <code>AccessControl</code> stage of the request.
	 */
	public static final int MTP_EXCEPTION_SECURITY_CHECK = 3;

	/**
	 * The request has thrown the exception during the <code>validator</code> stage of the request.
	 */
	public static final int MTP_EXCEPTION_VALIDATION = 4;

	/**
	 * The request has thrown the exception during the <code>modelRun</code> stage of the request.
	 */
	public static final int MTP_EXCEPTION_MODEL_RUN = 5;
	
	/**
	 * The request has thrown the exception during the <code>viewMapper</code> stage of the request.
	 */
	public static final int MTP_EXCEPTION_VIEW_MAPPER = 6;

	/**
	 * The request has thrown the exception during the <code>viewRun</code> stage of the request.
	 */
	public static final int MTP_EXCEPTION_VIEW_DISPATCHER = 7;

	/**
	 * The stage where the request has failed. It's one of the MTP_EXCEPTION_* values.
	 */
	int errorCode = 0;

	// Constructors
	public MTPException(String msg, Throwable t, int errorCode){
		super(msg, t);
		this.errorCode = errorCode;
	}
	public MTPException(String msg, int errorCode){
		super(msg);
		this.errorCode = errorCode;
	}
	public MTPException(String msg, Throwable t){
		super(msg,t);
	}
	public MTPException(String msg){
		super(msg);
	}
	
	// getters & setters
	public int getErrorCode() {
		return errorCode;
	}
	public void setErrorCode(int errorCode) {
		this.errorCode = errorCode;
	}
}
