package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import edu.uoc.pfc.j2ee.jalonsod.mtp.request.BooleanParameterInstance;

/**
 * File: BooleanParameter.java
 * Created: 2012-04-22
 * 
 * The Parameter configuration metadata for datatype <code>Boolean</code>.
 * 
 * @author Jos Alonso de Motta
 * @see BooleanParameterInstance
 */
public class BooleanParameter extends Parameter {
	Boolean defaultValue;

	/**
	 * Constructor of boolean parameter.
	 *  
	 * @throws ConfiguratorException Throws when received parameters are invalid
	 */
	protected BooleanParameter(String name, String datatype, boolean required,
			Validation validateMethod, boolean copyToModel,
			String modelAttribute, String defaultValue) throws ConfiguratorException{
		super(name, datatype, required, validateMethod, copyToModel, modelAttribute);
		if(!datatype.equalsIgnoreCase(Configurator.DATATYPE_BOOLEAN)){
			throw new ConfiguratorException("Cannot instantiate boolean parameter with datatype "+ datatype);
		}
		try{
			if(defaultValue!=null && !defaultValue.equals("") ){
				setDefaultValue(Boolean.parseBoolean(defaultValue));
			}else
				setDefaultValue(null);
		}catch (Exception e){
			throw new ConfiguratorException("Error setting default value for parameter " + name + " with datatype " + datatype);
		}
	}

	// getters & setters
	@Override
	public Boolean getDefaultValue() {
		return defaultValue;
	}
	@Override
	public void setDefaultValue(Object defaultValue) {
		setDefaultValue((Boolean)defaultValue);
	}
	public void setDefaultValue(Boolean defaultValue) {
		this.defaultValue = defaultValue;
	}
	@Override
	public Class<?> getDatatypeReference(){
		return Boolean.class;
	}
}
