package edu.uoc.pfc.j2ee.jalonsod.mtp.config;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Properties;

/**
 * File: Language.java
 * Created: 2012-04-22
 * 
 * A <code>language</code> is a user interface language supported by the application. A language
 * is a group of translated messages to be used by the user interface.
 * 
 * @author Jos Alonso de Motta
 * @see LanguageEntry
 */
public class Language {
	private String name;
	private String longName;
	private String messageFile;
	private Hashtable<String, LanguageEntry> entries;

	public Language(String name, String longName, String messageFile) throws ConfiguratorException {
		if(name==null||name.equals("")) throw new ConfiguratorException("Language element has null or empty name");
		if(messageFile==null||messageFile.equals("")) throw new ConfiguratorException("Language element " + name + " has null or empty message file name");
		setName(name);
		setLongName(longName);
		setMessageFile(messageFile);
		setEntries(new Hashtable<String, LanguageEntry>());
		loadEntries();
	}
	
	// getters & setters
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public String getLongName() {
		return longName;
	}
	public void setLongName(String longName) {
		this.longName = longName;
	}
	public String getMessageFile() {
		return messageFile;
	}
	public void setMessageFile(String messageFile) {
		this.messageFile = messageFile;
	}
	public Hashtable<String, LanguageEntry> getEntries() {
		return entries;
	}
	public void setEntries(Hashtable<String, LanguageEntry> entries) {
		this.entries = entries;
	}

	/**
	 * Search a languageEntry by key
	 * 
	 * @param key the key to search the entry.
	 * @return the value of the entry or null if not found.
	 */
	public LanguageEntry getLanguageEntryByKey(String key){
		return entries.get(key);
	}

	/**
	 * Load all the language entries in a properties file.
	 * 
	 * @throws ConfiguratorException throws when there is a problem loading the file.
	 */
	public void loadEntries() throws ConfiguratorException {
		Properties properties = new Properties();
		try {
			properties.load(this.getClass().getResourceAsStream("/" + getMessageFile()));
			Enumeration<?> entryNames = properties.propertyNames();
			while(entryNames.hasMoreElements()){
				String entryName = (String)entryNames.nextElement();
				getEntries().put(entryName, new LanguageEntry(entryName,
						properties.getProperty(entryName)));
			}
		} catch (FileNotFoundException e) {
			e.printStackTrace();
			throw new ConfiguratorException("FileNotFoundException while loading language " + getName() + " with file " + getMessageFile(), e);
		} catch (IOException e) {
			e.printStackTrace();
			throw new ConfiguratorException("IOException while loading language " + getName() + " with file " + getMessageFile(), e);
		}
	}
	
	@Override
	public String toString() {
		return "Language [name=" + name
				+ ", longName=" + longName
				+ ", messageFile=" + messageFile
				+ ", entries=" + entries
				+ "]";
	}
}
