package edu.uoc.pfc.j2ee.jalonsod.mtp.helper;

import java.util.logging.Logger;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Model;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestDataPrivate;

/**
 * File: ModelMapperImpl.java
 * Created: 2012-04-28
 * 
 * ModelMapper implementation from the framework.
 * The map algorithm is based on the MODEL parameter of the request.
 * 
 * @author Jos Alonso de Motta
 */
public class ModelMapperImpl implements ModelMapper {
	private final static Logger logger = Logger.getLogger(RequestData.MTP_LOGGER);
	public static final String MODEL_PARAMETER = "MODEL";

	@Override
	public void setRequestModel(RequestDataPrivate requestData) throws MTPException {
		Model selectedModel = null;
		// Model = MODEL attribute from request or defaultModel
		String modelParameter = requestData.getRequestParameter(MODEL_PARAMETER);
		logger.fine("Model parameter " + modelParameter + " received");
		if(modelParameter!=null){
			selectedModel = requestData.getConfigurator().getModelByKey(modelParameter);
			if(selectedModel==null){
				logger.warning("Requested model " + modelParameter + " not found in configuration! Default model will be selected.");
			}
		}
		if(selectedModel==null){
			selectedModel = requestData.getConfigurator().getDefaultModel();
			logger.fine("Default model " + selectedModel + " is selected");
		}else{
			logger.fine("Model " + selectedModel + " is selected");
		}
		requestData.setModel(selectedModel);
		try {
			Object modelInstance = selectedModel.getClassReference().newInstance();
			requestData.setModelInstance(modelInstance);
		} catch (InstantiationException e) {
			throw new MTPException("Error instantiating model object", e);
		} catch (IllegalAccessException e) {
			throw new MTPException("Error instantiating model object", e);
		}
	}
}
