package edu.uoc.pfc.j2ee.jalonsod.mtp.request;

import java.util.Date;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPUtils;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.DateParameter;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Parameter;

/**
 * File: DateParameterInstance.java
 * Created: 2012-05-01
 * 
 * Holds a request parameter value of type <code>java.sql.Date</code>.
 * 
 * @author Jos Alonso de Motta
 * @see DateParameter
*/
public class DateParameterInstance extends ParameterInstance {
	/**
	 * The value of the request parameter.
	 */
	Date value;

	public DateParameterInstance(Parameter parameter) {
		super(parameter);
		setValue(null);
	}

	@Override
	public Date getValue() {
		return value;
	}

	@Override
	public void setValue(Object value) {
		setValue((Date)value);
	}

	/**
	 * The setter of the value received as same datatype as the parameterInstance.
	 * 
	 * @param value the value to set.
	 */
	public void setValue(Date value) {
		this.value = value;
	}
	
	@Override
	public Date getDefaultValue() {
		return (Date)getParameter().getDefaultValue();
	}

	@Override
	public void setStringValue(String value) throws MTPException {
		try{
			if(value!=null && !value.equals("")){
				setValue(MTPUtils.parseDate(value, ((DateParameter)parameter).getDateFormat()));
			}else{
				setValueAsDefault();
			}
		}catch(Exception e) {
			throw new MTPException("Error while parsing value " + value + " from String to " + getParameter().getDatatype(), e);
		}
	}


	@Override
	public String toString() {
		return "DateParameterInstance [value=" + value
				+ ", parameter=" + parameter
				+ ", validationStatus=" + validationStatus
				+ "]";
	}
}
