package edu.uoc.pfc.j2ee.jalonsod.mtp.request;

import java.util.Enumeration;
import java.util.Hashtable;

import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Form;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Parameter;

/**
 * File: FormInstance.java
 * Created: 2012-05-01
 * 
 * Holds the request parameter values that has been declared by the related <code>form</code>
 * metadata object.
 * 
 * @author Jos Alonso de Motta
 * @see Form
*/
public class FormInstance {
	/**
	 * The form metadata object wich this formInstance instantiates.
	 */
	Form form;
	
	/**
	 * The request parameter values declared in the related form metadata object.
	 */
	Hashtable<String, ParameterInstance> parameters;

	public FormInstance(Form form){
		setForm(form);
		loadParameters();
	}
	
	// getters & setters
	public Form getForm() {
		return form;
	}
	public void setForm(Form form) {
		this.form = form;
	}
	public Hashtable<String, ParameterInstance> getParameters() {
		return parameters;
	}
	public void setParameters(Hashtable<String, ParameterInstance> parameters) {
		this.parameters = parameters;
	}
	
	/**
	 * Populates the <code>parameters</code> with <code>null</code> values. The list is created
	 * using the <code>form</code> metadata parameters.
	 */
	public void loadParameters(){
		Enumeration<Parameter> parametersEnumerator = form.getParameters().elements();
		parameters = new Hashtable<String, ParameterInstance>();
		while(parametersEnumerator.hasMoreElements()){
			Parameter parameter = parametersEnumerator.nextElement();
			parameters.put(parameter.getName(), ParameterInstance.createParameterInstance(parameter));
		}
	}

	@Override
	public String toString() {
		return "FormInstance [form=" + form
				+ ", parameters=" + parameters
				+ "]";
	}
}
