package edu.uoc.pfc.j2ee.jalonsod.mtp.request;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.IntegerParameter;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Parameter;

/**
 * File: IntegerParameterInstance.java
 * Created: 2012-05-01
 * 
 * Holds a request parameter value of type <code>Integer</code>.
 * 
 * @author Jos Alonso de Motta
 * @see IntegerParameter
*/
public class IntegerParameterInstance extends ParameterInstance {
	/**
	 * The value of the request parameter.
	 */
	Integer value;

	public IntegerParameterInstance(Parameter parameter) {
		super(parameter);
		setValue(null);
	}

	@Override
	public Integer getValue() {
		return value;
	}

	@Override
	public void setValue(Object value) {
		setValue((Integer)value);
	}

	/**
	 * The setter of the value received as same datatype as the parameterInstance.
	 * 
	 * @param value the value to set.
	 */
	public void setValue(Integer value) {
		this.value = value;
	}

	@Override
	public Integer getDefaultValue() {
		return (Integer)getParameter().getDefaultValue();
	}

	@Override
	public void setStringValue(String value) throws MTPException {
		try{
			if(value!=null && !value.equals("")){
				setValue(Integer.parseInt(value));
			}else{
				setValueAsDefault();
			}
		}catch(Exception e) {
			throw new MTPException("Error while parsing value " + value + " from String to " + getParameter().getDatatype(), e);
		}
	}

	@Override
	public String toString() {
		return "IntegerParameterInstance [value=" + value
				+ ", parameter=" + parameter
				+ ", validationStatus=" + validationStatus
				+ "]";
	}
}
