package edu.uoc.pfc.j2ee.jalonsod.mtp.request;

import edu.uoc.pfc.j2ee.jalonsod.mtp.MTPException;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.StringParameter;
import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Parameter;

/**
 * File: StringParameterInstance.java
 * Created: 2012-05-01
 * 
 * Holds a request parameter value of type <code>String</code>.
 * 
 * @author Jos Alonso de Motta
 * @see StringParameter
*/
public class StringParameterInstance extends ParameterInstance {
	/**
	 * The value of the request parameter.
	 */
	String value;

	public StringParameterInstance(Parameter parameter) {
		super(parameter);
		setValue(null);
	}

	@Override
	public String getValue() {
		return value;
	}

	@Override
	public void setValue(Object value) {
		setValue((String)value);
	}

	/**
	 * The setter of the value received as same datatype as the parameterInstance.
	 * 
	 * @param value the value to set.
	 */
	public void setValue(String value) {
		this.value = value;
	}

	@Override
	public String getDefaultValue() {
		return (String)getParameter().getDefaultValue();
	}

	@Override
	public void setStringValue(String value) throws MTPException {
		if(value!=null && !value.equals("")){
			setValue(value);
		}else{
			setValueAsDefault();
		}
	}

	@Override
	public String toString() {
		return "StringParameterInstance [value=" + value
				+ ", parameter=" + parameter
				+ ", validationStatus=" + validationStatus
				+ "]";
	}
}
