package edu.uoc.pfc.j2ee.jalonsod.mtp.request.taglib;

import java.io.IOException;

import javax.servlet.jsp.JspException;
import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.BodyContent;
import javax.servlet.jsp.tagext.BodyTagSupport;

import edu.uoc.pfc.j2ee.jalonsod.mtp.helper.ContextFactory;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.ParameterInstance;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: GetFormInstanceParameter.java
 * Created: 2012-05-17
 * 
 * Support class for getFormInstanceParameter tag. Loads into the page context the parameterInstance
 * object of the form instance (not the value).
 * 
 * @author Jos Alonso de Motta
 */
public class GetFormInstanceParameter extends BodyTagSupport {
	private static final long serialVersionUID = 1L;
	
	private String name;
	
	@Override
	public int doStartTag() throws JspException{
		ParameterInstance parameterInstance = null;
		try {
			RequestData requestData = ContextFactory.getRequestData(pageContext.getRequest());
			if(requestData!=null){
				parameterInstance = requestData.getFormInstance().getParameters().get(name);
			}
			pageContext.setAttribute(Constants.MTP_TAGLIB_VARIABLE_REQUEST_FORM_INSTANCE_PARAMETER, parameterInstance, PageContext.PAGE_SCOPE);
		} catch (Exception e) {
			throw new JspTagException("doStartTag: " + e.getMessage(), e);
		}
		return EVAL_BODY_BUFFERED;
	}

	@Override
	public int doAfterBody() throws JspTagException{
		BodyContent bodyContent = getBodyContent();
		try {
			bodyContent.writeOut(getPreviousOut());
		} catch (IOException e) {
			throw new JspTagException("doAfterBody: " + e.getMessage(), e);
		}
		bodyContent.clearBody();
		return SKIP_BODY;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}
}
