package edu.uoc.pfc.j2ee.jalonsod.mtp.request.taglib;

import java.io.IOException;
import java.util.Enumeration;

import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.tagext.BodyContent;
import javax.servlet.jsp.tagext.BodyTagSupport;

import edu.uoc.pfc.j2ee.jalonsod.mtp.config.Language;
import edu.uoc.pfc.j2ee.jalonsod.mtp.helper.ContextFactory;
import edu.uoc.pfc.j2ee.jalonsod.mtp.request.RequestData;

/**
 * File: GetLanguages.java
 * Created: 2012-05-15
 * 
 * Support class for getLanguages tag. Iterates over supported user interface languages. Nest
 * <code>getProperty</code> tag inside to read language properties.
 * 
 * @author Jos Alonso de Motta
 */
public class GetLanguages extends BodyTagSupport {
	private static final long serialVersionUID = 1L;
	
	Enumeration<Language> enumerator;
	
	@Override
	public int doStartTag(){
		RequestData requestData = ContextFactory.getRequestData(pageContext.getRequest());
		enumerator = requestData.getLanguages().elements();
		if(enumerator.hasMoreElements()){
			pageContext.setAttribute(Constants.MTP_TAGLIB_VARIABLE_LANGUAGE, enumerator.nextElement(), PageContext.PAGE_SCOPE);
			return EVAL_BODY_BUFFERED;
		}else{
			pageContext.setAttribute(Constants.MTP_TAGLIB_VARIABLE_LANGUAGE, null, PageContext.PAGE_SCOPE);
			return SKIP_BODY;
		}
	}

	@Override
	public int doAfterBody() throws JspTagException{
		BodyContent bodyContent = getBodyContent();
		try {
			bodyContent.writeOut(getPreviousOut());
		} catch (IOException e) {
			throw new JspTagException("doAfterBody: " + e.getMessage(), e);
		}
		bodyContent.clearBody();
		if(enumerator.hasMoreElements()){
			pageContext.setAttribute(Constants.MTP_TAGLIB_VARIABLE_LANGUAGE, enumerator.nextElement(), PageContext.PAGE_SCOPE);
			return EVAL_BODY_AGAIN;
		}else{
			pageContext.setAttribute(Constants.MTP_TAGLIB_VARIABLE_LANGUAGE, null, PageContext.PAGE_SCOPE);
			return SKIP_BODY;
		}
	}
}
